"""Task "Action" and Profile "condition" dictionary"""

#                                                                                      #
# actionc: Task "Action" and Profile "condition" dictionary                            #
#                                                                                      #
#  Provide the master lookup for a given <code>nnn</code> xml statement                #
#  level 1 key = the code (nnn, above) or screen element type                          #
#       If a code, the last character is 't' for 't', 'e' for event, 's' for state     #
#   numargs subkey = the maximum number of argn xml lines in the action                #
#      if it = 99, then this is a referral to another entry, which is identified       #
#      in 'args'                                                                       #
#   args subkey = the specific arg number  keys with a 's' or 'e' are Profile          #
#    conditions                                                                        #
#        ...'e'=event, 's'=state, 't'=task                                             #
#   display subkey = the name to output - required                                     #
#   reqargs subkey = the requirement arg statement numbers for evaluation - optional   #
#   evalargs subkey = formula for evaluation - optional                                #
#      'some_string:' for str or int xml values                                        #
#      ["e", ", name"] ...evaluate value to determine if it is 'selected'.             #
#                                                                                      #
#      ['some_string:', 'l', 'lookup-code] for actiont dictionary lookup for specific  #
#       code.                                                                          #
#                                                                                      #

from collections import namedtuple

ActionCode = namedtuple(  # noqa: PYI024
    "ActionCode",
    ["redirect", "args", "name", "category", "canfail"],
)
ArgumentCode = namedtuple(  # noqa: PYI024
    "ArgumentCode",
    ["arg_id", "arg_required", "arg_name", "arg_type", "arg_eval"],
)
action_codes = {
    "1000e": ActionCode(
        "",
        [["0", True, "", "0", ["Priority=", "l", "4s"]]],
        "Display Unlocked",
        "",
        "",
    ),
    "1000s": ActionCode("", [], "Plugin", "", ""),
    "1000t": ActionCode("", [], "Plugin", "", ""),
    "100s": ActionCode("", [], "Airplane Mode", "", ""),
    "100t": ActionCode(
        "",
        [
            ["0", True, "For", "1", "Number="],
            ["1", True, "Web Search", "3", ["e", "Info"]],
        ],
        "Search",
        "104",
        "False",
    ),
    "101t": ActionCode(
        "",
        [
            ["0", True, "Camera", "0", "Camera"],
            ["1", True, "Filename", "1", "Filename"],
            ["2", True, "Naming Sequence", "0", "Naming Sequence"],
            ["3", True, "Insert In Gallery", "3", "Insert In Gallery"],
            ["4", True, "Discreet", "3", "Discreet"],
            ["5", False, "Resolution", "1", "Resolution"],
            ["6", True, "Scene Mode", "0", "Scene Mode"],
            ["7", True, "White Balance", "0", "White Balance"],
            ["8", True, "Flash Mode", "0", "Flash Mode"],
            ["9", True, "Focus Mode", "0", "Focus Mode"],
        ],
        "Take Photo",
        "65",
        "True",
    ),
    "102t": ActionCode(
        "",
        [["0", True, "File", "1", "File"], ["1", False, "Mime Type", "1", "Mime Type"]],
        "Open File",
        "50",
        "True",
    ),
    "103s": ActionCode("", [["0", True, "", "0", "Level="]], "Light Level", "", ""),
    "1040876951t": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", "Timeout="],
            ["4", True, "", "1", ["", "e", ",Structure Output (JSON, etc)"]],
        ],
        "AutoInput UI Query",
        "",
        "",
    ),
    "1040969826t": ActionCode(
        "1040876951t",
        [],
        "Muzei Wallpaper: Next Artwork",
        "",
        "",
    ),
    "104s": ActionCode("", [], "Pressure", "", ""),
    "104t": ActionCode(
        "",
        [
            ["0", True, "URL", "1", "URL="],
            ["1", True, "Package/App Name", "2", "Package/App Name="],
            ["2", True, "'Open With' Dialog", "3", ["e", ", 'Open With' Dialog"]],
            ["3", True, "'Open With' Title", "1", ", 'Open With' Title="],
        ],
        "Browse URL",
        "80",
        "True",
    ),
    "105s": ActionCode("", [], "Media Button", "", ""),
    "105t": ActionCode(
        "",
        [
            ["0", False, "Text", "1", "Text="],
            ["1", True, "Add", "3", ["e", ", Add"]],
            ["2", False, "Image", "1", "Image="],
            ["3", True, "Is Sensitive Data", "3", "Is Sensitive Data"],
        ],
        "Set Clipboard",
        "104",
        "True",
    ),
    "106s": ActionCode("", [], "Magnetic Field", "", ""),
    "107361459t": ActionCode("1040876951t", [], "AutoInput Actions V2", "", ""),
    "107s": ActionCode("", [], "Missed Call", "", ""),
    "1094115366t": ActionCode("1040876951t", [], "AutoCast Device Settings", "", ""),
    "1099157652t": ActionCode("1040876951t", [], "AutoTools Json Write", "", ""),
    "109t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "109"]],
            ["1", False, "Image", "1", "Image"],
            ["2", True, "Scale", "3", ["e", ", Scale"]],
            ["3", True, "Crop", "3", ["e", ", Crop"]],
            ["4", True, "Center", "3", ["e", ", Center"]],
        ],
        "Set Wallpaper",
        "40",
        "True",
    ),
    "10s": ActionCode(
        "",
        [["0", True, "", "0", ["Set=", "l", "10s"]]],
        "Power",
        "",
        "",
    ),
    "110s": ActionCode(
        "",
        [
            ["0", True, "", "0", ["", "e", "2G"]],
            ["1", True, "", "0", ["", "e", "3G"]],
            ["2", True, "", "0", ["", "e", "3G-HSPA"]],
            ["3", True, "", "0", ["", "e", "4G"]],
            ["4", True, "", "0", ["", "e", "5G"]],
            ["5", True, "", "0", [", Active=", "l", "160"]],
        ],
        "Mobile Network",
        "",
        "",
    ),
    "111t": ActionCode(
        "",
        [
            ["0", False, "Recipient(s)", "1", "Recipient(s)"],
            ["1", False, "Subject", "1", "Subject"],
            ["2", False, "Message", "1", "Message"],
            ["3", True, "Attachment", "1", "Attachment"],
        ],
        "Compose MMS",
        "90",
        "False",
    ),
    "1120274117t": ActionCode("1040876951t", [], "Locus Map", "", ""),
    "112t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name"],
            ["1", True, "Terminal", "3", "Terminal"],
            ["2", False, "Pass Variables", "1", "Pass Variables"],
        ],
        "Run SL4A Script",
        "35",
        "True",
    ),
    "1130446693t": ActionCode("1040876951t", [], "AutoTools Launcher", "", ""),
    "1132319851t": ActionCode("1040876951t", [], "AutoSheets Add Sheet", "", ""),
    "1133159835e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoShare Process Text",
        "",
        "",
    ),
    "1138194991s": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", "Structure Output (JSON (etc)"]],
        ],
        "AutoWear State",
        "",
        "",
    ),
    "1138588429t": ActionCode("1040876951t", [], "Join Send Query", "", ""),
    "113t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", "Set"],
            [
                "1",
                True,
                "Keep Wi-Fi when turning on",
                "3",
                "Keep Wi-Fi when turning on",
            ],
        ],
        "WiFi Tether (Hotspot)",
        "80",
        "True",
    ),
    "114t": ActionCode(
        "",
        [["0", True, "Set", "3", "Set"]],
        "USB Tether",
        "80",
        "False",
    ),
    "1150542767e": ActionCode("1040876951t", [], "Tap Tap Plugin", "", ""),
    "115t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ""],
            ["1", True, "Data", "1", ""],
            ["2", True, "Store Result In", "1", ""],
        ],
        "Test",
        "140",
        "True",
    ),
    "1164968315t": ActionCode("1040876951t", [], "AutoSpotify Play Media", "", ""),
    "1165325195t": ActionCode("1040876951t", [], "AutoTools Web Screen", "", ""),
    "116t": ActionCode(
        "",
        [
            ["0", True, "Server:Port", "1", "Server:Port"],
            ["1", False, "Path", "1", "Path"],
            ["2", False, "Data / File", "1", "Data / File"],
            ["3", False, "Cookies", "1", "Cookies"],
            ["4", False, "User Agent", "1", "User Agent"],
            ["5", True, "Timeout", "0", "Timeout"],
            ["6", False, "Content Type", "1", "Content Type"],
            ["7", False, "Output File", "1", "Output File"],
            ["8", True, "Trust Any Certificate", "3", "Trust Any Certificate"],
        ],
        "HTTP Post",
        "80",
        "True",
    ),
    "117240295t": ActionCode("1040876951t", [], "AutoWear Input", "", ""),
    "117t": ActionCode(
        "",
        [
            ["0", True, "Server:Port", "1", "Server:Port"],
            ["1", False, "Path", "1", "Path"],
            ["2", False, "Attributes", "1", "Attributes"],
            ["3", False, "Cookies", "1", "Cookies"],
            ["4", False, "User Agent", "1", "User Agent"],
            ["5", True, "Timeout", "0", "Timeout"],
            ["6", True, "Trust Any Certificate", "3", "Trust Any Certificate"],
        ],
        "HTTP Head",
        "80",
        "True",
    ),
    "1186637727t": ActionCode("1040876951t", [], "KWGT Kustom Widget Maker", "", ""),
    "118t": ActionCode(
        "",
        [
            ["0", True, "Server:Port", "1", "Server:Port"],
            ["1", False, "Path", "1", "Path"],
            ["2", False, "Attributes", "1", "Attributes"],
            ["3", False, "Cookies", "1", "Cookies"],
            ["4", False, "User Agent", "1", "User Agent"],
            ["5", True, "Timeout", "0", "Timeout"],
            ["6", False, "Mime Type", "1", "Mime Type"],
            ["7", False, "Output File", "1", "Output File"],
            ["8", True, "Trust Any Certificate", "3", "Trust Any Certificate"],
        ],
        "HTTP Get",
        "80",
        "True",
    ),
    "119t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "119"]],
            ["1", False, "Address", "1", ", Address="],
            ["2", False, "Lat,Long", "1", ", Lat, Long="],
            ["3", True, "Zoom", "0", ", Zoom="],
            ["4", False, "Label", "1", ", Label="],
        ],
        "Open Map",
        "60",
        "True",
    ),
    "120s": ActionCode(
        "",
        [["0", True, "", "0", ["Is=", "l", "120s"]]],
        "Orientation",
        "",
        "",
    ),
    "122375409t": ActionCode("1040876951t", [], "AutoWeb Web Services", "", ""),
    "122s": ActionCode(
        "",
        [["0", True, "", "0", ["Is=", "l", "122s"]]],
        "Display Orientation",
        "",
        "",
    ),
    "123s": ActionCode(
        "",
        [["0", True, "", "1", ["", "e", "switch_set"]]],
        "Display State",
        "",
        "",
    ),
    "123t": ActionCode(
        "",
        [
            ["0", True, "Command", "1", "Command="],
            ["1", True, "Timeout (Seconds)", "0", ", Timeout="],
            ["2", True, "Use Root", "3", ["e", ", Use Root"]],
            ["3", False, "Store Output In", "1", ", Store Output In="],
            ["4", False, "Store Errors In", "1", ", Store Errors In="],
            ["5", False, "Store Result In", "1", ", Timeout="],
            ["6", True, "Use Global Namespace", "3", "Use Global Namespace"],
            ["7", True, "Use Tasker Settings", "3", "Use Tasker Settings"],
        ],
        "Run Shell",
        "35",
        "True",
    ),
    "1246578872t": ActionCode("1040876951t", [], "AutoWear Notification", "", ""),
    "124t": ActionCode(
        "",
        [["0", True, "Path", "0", "Path"], ["1", True, "Writeable", "3", "Writeable"]],
        "Remount",
        "50",
        "False",
    ),
    "1250249549t": ActionCode("1040876951t", [], "AutoInput Screen Off/On", "", ""),
    "1256900802t": ActionCode("1040876951t", [], "Termux", "", ""),
    "125s": ActionCode("", [], "Proximity Sensor", "", ""),
    "125t": ActionCode(
        "",
        [
            ["0", False, "Recipient(s)", "1", "Recipient(s)="],
            ["1", False, "Subject", "1", ", Subject="],
            ["2", False, "Message", "1", ", Message="],
        ],
        "Compose Email",
        "80",
        "False",
    ),
    "1269159260t": ActionCode("1040876951t", [], "Calendar Task", "", ""),
    "126t": ActionCode(
        "",
        [
            ["0", True, "Value", "1", "Value="],
            ["1", True, "Stop", "3", ["e", ", Stop"]],
            [
                "2",
                True,
                "Local Variable Passthrough",
                "3",
                ["e", ", Local Variable Passthrough"],
            ],
            [
                "3",
                True,
                "Replace On Passthrough",
                "3",
                ["e", ", Replace On Passthrough"],
            ],
            ["4", False, "Limit Passthrough To", "1", ", Limit Passthrough To="],
        ],
        "Return",
        "105",
        "False",
    ),
    "129t": ActionCode(
        "",
        [
            ["0", True, "Code", "1", "Code="],
            ["1", False, "Libraries", "1", ", Libraries="],
            ["2", True, "Auto Exit", "3", ["e", ", Auto Exit"]],
            ["3", True, "Timeout (Seconds)", "0", ", Timeout="],
        ],
        "JavaScriptlet",
        "35",
        "True",
    ),
    "12s": ActionCode("", [], "HDMI Plugged", "", ""),
    "1304982781t": ActionCode("1040876951t", [], "AutoTools Dialog", "", ""),
    "130t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Priority", "0", ", Priority="],
            ["2", False, "Parameter 1 (%par1)", "1", ", Parameter 1="],
            ["3", False, "Parameter 2 (%par2)", "1", ", Parameter 2="],
            ["4", False, "Return Value Variable", "1", ", Return Value Variable="],
            ["5", True, "Stop", "3", ["e", ", Stop"]],
            [
                "6",
                True,
                "Local Variable Passthrough",
                "3",
                ["e", ", Local Variable Passthrough"],
            ],
            ["7", False, "Limit Passthrough To", "1", ", Limit Passthrough To="],
            ["8", True, "Reset Return Variable", "3", ["e", ", Reset Return Variable"]],
            [
                "9",
                True,
                "Allow Overwrite Variables",
                "3",
                ["e", ", Allow Overwrite Variables"],
            ],
            [
                "10",
                True,
                "Structure Output (JSON, etc)",
                "3",
                ["e", ", Structure Output (JSON, etc)"],
            ],
        ],
        "Perform Task",
        "105",
        "True",
    ),
    "131t": ActionCode(
        "",
        [
            ["0", True, "Path", "1", "Path="],
            ["1", False, "Libraries", "1", ", Libraries="],
            ["2", True, "Auto Exit", "3", ["e", ", Auto Exit"]],
            ["3", True, "Timeout (Seconds)", "0", "Timeout (Seconds)"],
        ],
        "JavaScript",
        "35",
        "True",
    ),
    "1339291165t": ActionCode("1040876951t", [], "AutoWeb Download", "", ""),
    "1339942270t": ActionCode("1040876951t", [], "SharpTools Thing", "", ""),
    "133t": ActionCode(
        "",
        [
            ["0", True, "Set", "0", ["Set=", "l", "133"]],
            ["1", True, "Value", "0", "Value"],
            ["2", True, "Value", "3", ["e", ", Value"]],
        ],
        "Set Tasker Pref",
        "110",
        "True",
    ),
    "1344888481e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "Notification Listener",
        "",
        "",
    ),
    "134e": ActionCode("", [], "Card Mounted", "", ""),
    "134t": ActionCode(
        "",
        [["0", False, "Action", "1", "Action="]],
        "Query Action",
        "110",
        "True",
    ),
    "135e": ActionCode("", [], "Card Unmounted", "", ""),
    "135s": ActionCode("", [], "Auto-Sync", "", ""),
    "135t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Set=", "l", "135"]],
            ["1", True, "Number", "0", ", Number="],
            ["2", True, "Label", "1", ", Label="],
        ],
        "Goto",
        "105",
        "True",
    ),
    "136e": ActionCode("", [], "Card Removed", "", ""),
    "136s": ActionCode("", [], "VPN Connected", "", ""),
    "136t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Sound Effects",
        "20",
        "False",
    ),
    "137t": ActionCode(
        "",
        [
            ["0", True, "With Error", "3", ["e", "Stop"]],
            ["1", False, "Task", "1", " Task="],
        ],
        "Stop",
        "105",
        "False",
    ),
    "1384093265t": ActionCode("1040876951t", [], "Calendar Task", "", ""),
    "138t": ActionCode(
        "",
        [["0", True, "Icon", "4", "Icon="]],
        "Set Tasker Icon",
        "110",
        "False",
    ),
    "139t": ActionCode("", [], "Disable", "110", "False"),
    "140618776t": ActionCode("1040876951t", [], "AutoWear Toast", "", ""),
    "140s": ActionCode(
        "",
        [["0", True, "", "0", "From="], ["1", True, "", "0", ", To="]],
        "Battery Level",
        "",
        "",
    ),
    "140t": ActionCode(
        "",
        [["0", False, "Old", "1", "Old="], ["1", True, "New", "1", ", New="]],
        "Change Icon Set",
        "110",
        "False",
    ),
    "1410790256t": ActionCode("1040876951t", [], "AutoWear Floating Icon", "", ""),
    "1411074191t": ActionCode("1040876951t", [], "AutoSheets Add Rows", "", ""),
    "141s": ActionCode("", [], "Battery Temperature", "", ""),
    "142s": ActionCode("", [["0", True, "", "1", "Name="]], "Profile Active", "", ""),
    "142t": ActionCode(
        "",
        [["0", True, "Task", "1", "Task="], ["1", False, "Action", "1", ", Action="]],
        "Edit Task",
        "110",
        "False",
    ),
    "143s": ActionCode("", [["0", True, "", "1", "Name="]], "Task Running", "", ""),
    "143t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", False, "Element", "1", ", Element="],
        ],
        "Edit Scene",
        "110",
        "False",
    ),
    "1446679033t": ActionCode("1040876951t", [], "AutoTools Time", "", ""),
    "1446697909t": ActionCode("1040876951t", [], "AutoWear Dialog", "", ""),
    "1446874931t": ActionCode("1040876951t", [], "AutoTools Json Read", "", ""),
    "1447159672t": ActionCode("1040876951t", [], "AutoTools Text", "", ""),
    "1447244736t": ActionCode("1040876951t", [], "AutoTools Action Wait", "", ""),
    "144741820t": ActionCode(
        "1040876951t",
        [],
        "AutoNotification Hide Notification Icons",
        "",
        "",
    ),
    "1452528931t": ActionCode("1040876951t", [], "AutoContacts Query 2.0", "", ""),
    "145s": ActionCode("", [], "Signal Strength", "", ""),
    "1461810131t": ActionCode("1040876951t", [], "AutoSheets Update Cells", "", ""),
    "147s": ActionCode("", [], "Unread Text", "", ""),
    "147t": ActionCode(
        "",
        [["0", True, "Section", "0", ["Section=", "l", "147"]]],
        "Show Prefs",
        "110",
        "False",
    ),
    "1482108003t": ActionCode("1040876951t", [], "AutoSpotify Player State", "", ""),
    "148s": ActionCode("", [], "Pen Out", "", ""),
    "148t": ActionCode("", [], "Show Runlog", "110", "False"),
    "149s": ActionCode("", [], "Pen Menu", "", ""),
    "14s": ActionCode("", [], "Power Save Mode", "", ""),
    "1508929357t": ActionCode("1040876951t", [], "AutoTools Array", "", ""),
    "150s": ActionCode(
        "",
        [["0", True, "", "0", ["Is=", "l", "150s"]]],
        "USB Connected",
        "",
        "",
    ),
    "150t": ActionCode("", [["0", True, "Set", "3", "Set"]], "Keyguard", "40", "False"),
    "1520257414e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoNotification Intercept",
        "",
        "",
    ),
    "152t": ActionCode(
        "",
        [["0", True, "Name", "1", "Name="], ["1", True, "Icon", "4", ", Icon="]],
        "Set Widget Icon",
        "110",
        "False",
    ),
    "153t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "153"]],
            ["1", True, "Source", "0", ["Source=", "l", "153a"]],
            ["2", True, "Variable", "1", ", Variable="],
        ],
        "Import Data",
        "110",
        "True",
    ),
    "154s": ActionCode("", [], "Active User", "", ""),
    "155t": ActionCode(
        "",
        [["0", True, "Name", "1", "Name="], ["1", False, "Label", "1", ", Label="]],
        "Set Widget Label",
        "110",
        "False",
    ),
    "1563355455t": ActionCode(
        "1040876951t",
        [],
        "AutoNotification Buttons Notification",
        "",
        "",
    ),
    "1563799945t": ActionCode("1040876951t", [], "Secure Settings", "", ""),
    "156t": ActionCode(
        "",
        [
            ["0", True, "Format", "0", ["Format=", "l", "156"]],
            ["1", True, "Locality", "0", ["Locality=", "l", "156a"]],
            ["2", True, "Beat Timing", "0", ", Best Timing="],
            ["3", True, "Score", "1", ", Score="],
        ],
        "MIDI Play",
        "65",
        "False",
    ),
    "157t": ActionCode(
        "",
        [
            ["0", True, "Label", "1", "Label"],
            ["1", True, "Icon", "4", "Icon"],
            ["2", True, "Collapse Panel On Click", "3", "Collapse Panel On Click"],
        ],
        "Quick Setting Add",
        "104",
        "False",
    ),
    "158t": ActionCode(
        "",
        [["0", True, "Label", "1", "Label"]],
        "Quick Setting Remove",
        "104",
        "False",
    ),
    "159t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Set", "0", ["Set=", "l", "switch_set"]],
        ],
        "Profile Status",
        "110",
        "True",
    ),
    "15t": ActionCode(
        "",
        [
            ["0", False, "Title", "1", "Title"],
            ["1", True, "Code", "1", "Code"],
            ["2", True, "Allow Cancel", "3", ["e", "Allow Cancel"]],
            ["3", True, "Remember Till Off", "3", ["e", "Remember Till Off"]],
            ["4", True, "Full Screen", "3", ["e", "Full Screen"]],
            ["5", False, "Background Image", "1", ", Background Image="],
            ["6", True, "Layout", "1", ", Layout="],
        ],
        "Lock",
        "40",
        "False",
    ),
    "1600958131t": ActionCode("1040876951t", [], "AutoBubbles Create Bubble", "", ""),
    "160s": ActionCode(
        "",
        [
            ["0", True, "", "1", "SSID="],
            ["1", True, "", "1", ", MAC="],
            ["2", True, "", "1", ", IP"],
            ["3", True, "", "0", ["Active=", "l", "160"]],
        ],
        "Wifi Connected",
        "",
        "",
    ),
    "161s": ActionCode("", [], "Ethernet Connect", "", ""),
    "161t": ActionCode(
        "",
        [
            ["0", False, "Task", "1", "Task="],
            ["1", False, "Task", "1", ", Task="],
            ["2", False, "Task", "1", ", Task="],
            ["3", False, "Task", "1", ", Task="],
        ],
        "Setup App Shortcuts",
        "110",
        "False",
    ),
    "1620773086t": ActionCode("1040876951t", [], "SharpTools A Thing", "", ""),
    "162t": ActionCode(
        "",
        [
            ["0", True, "Number", "0", ["Number=", "l", "162"]],
            ["1", False, "Task", "1", ", Task="],
            ["2", True, "Status", "0", [", Status=", "l", "162a"]],
            [
                "3",
                True,
                "Can Use On Locked Device",
                "3",
                ["e", ", Can Use On Locked Device"],
            ],
            ["4", False, "Long Click Task", "1", ", Long Click Task="],
            ["5", False, "Double Click Task", "1", ", Double Click Task="],
            ["6", False, "Subtitle", "1", ", Subtitle="],
            ["7", False, "Icon", "1", ", Icon="],
            ["8", False, "Label", "1", ", Label="],
            ["9", False, "Command", "1", ", Command="],
            ["10", False, "Long Click Command", "1", ", Long Click Command="],
            ["11", False, "Double Click Command", "1", ", Double Click Command="],
            ["12", False, "Command Prefix", "1", ", Command Prefix="],
        ],
        "Set up Quick Setting Tile",
        "110",
        "False",
    ),
    "1643249237t": ActionCode("1040876951t", [], "Tools & AmazFit", "", ""),
    "1644316156t": ActionCode("1040876951t", [], "AutoNotification Reply", "", ""),
    "1645272907e": ActionCode("", [], "CalendarTask", "", ""),
    "1646792910t": ActionCode("1040876951t", [], "AutoTools Secure Settings", "", ""),
    "165s": ActionCode("", [], "Variable Value", "", ""),
    "165t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "165"]],
            ["1", True, "Hours", "0", ", Minutes="],
            ["2", True, "Minutes", "0", "Minutes"],
            ["3", False, "Label", "1", "Label"],
        ],
        "Cancel Alarm",
        "104",
        "False",
    ),
    "166160670t": ActionCode("1040876951t", [], "AutoVoice Natural Language", "", ""),
    "1664218170e": ActionCode(
        "",
        [["3", True, "", "5", ["", "e", ", Structure Output (JSON, etc)"]]],
        "AutoVoice Natural Language",
        "",
        "",
    ),
    "1668911626e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "Join",
        "",
        "",
    ),
    "166t": ActionCode("", [], "Show Alarms", "104", "False"),
    "1677547919t": ActionCode("1040876951t", [], "AutoNotification Actions", "", ""),
    "1687767515t": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoInput Modes",
        "",
        "",
    ),
    "1691829355e": ActionCode(
        "",
        [["0", True, "", "5", ""]],
        "SharpTools Thing",
        "",
        "",
    ),
    "16s": ActionCode("", [], "Device Idle", "", ""),
    "16t": ActionCode("", [], "System Lock", "40", "False"),
    "170s": ActionCode("", [], "Wifi Near", "", ""),
    "171109731t": ActionCode("1040876951t", [], "AutoWeb Authentication", "", ""),
    "171t": ActionCode(
        "",
        [
            ["0", True, "Frequency", "0", "Frequency="],
            ["1", True, "Duration", "0", ", Duration="],
            ["2", True, "Amplitude", "0", ", Amplitude"],
            ["3", True, "Stream", "0", ["Stream=", "l", "171"]],
            ["4", False, "Do At Time", "1", "Do At Time"],
        ],
        "Beep",
        "10",
        "False",
    ),
    "172t": ActionCode(
        "",
        [
            ["0", True, "Text", "1", "Text="],
            ["1", True, "Frequency", "0", ", Frequency="],
            ["2", True, "Speed", "0", ", Speed="],
            ["3", True, "Amplitude", "0", ", Amplitude="],
            ["4", True, "Stream", "0", [", Stream=", "l", "171"]],
        ],
        "Morse",
        "10",
        "False",
    ),
    "1732635924t": ActionCode("1040876951t", [], "AutoInput Action", "", ""),
    "173t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "173"]],
            ["1", True, "Package/App Name", "2", "Package/App Name"],
        ],
        "Network Access",
        "80",
        "False",
    ),
    "1754437993t": ActionCode("1040876951t", [], "AutoVoice Recognition", "", ""),
    "175s": ActionCode("", [], "Dreaming", "", ""),
    "175t": ActionCode(
        "",
        [["0", True, "Mode", "0", ["Mode=", "l", "175"]]],
        "Power Mode",
        "104",
        "False",
    ),
    "1764880755t": ActionCode("1040876951t", [], "AutoCast Best Guess", "", ""),
    "176t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Insert In Gallery", "3", ["e", ", Insert In Gallery"]],
        ],
        "Take Screenshot",
        "40",
        "True",
    ),
    "177t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Haptic Feedback",
        "20",
        "False",
    ),
    "1788518030e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoInput Key",
        "",
        "",
    ),
    "1795842217t": ActionCode("1040876951t", [], "AutoLaunch", "", ""),
    "1804737413t": ActionCode("1040876951t", [], "AutoWear Secure Settings", "", ""),
    "180s": ActionCode("", [], "Temperature", "", ""),
    "1810865467t": ActionCode("1040876951t", [], "AutoSheets Get Data", "", ""),
    "1810891651t": ActionCode("1040876951t", [], "AutoSheets Get Cell", "", ""),
    "1825107102e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoNotification",
        "",
        "",
    ),
    "1828597236t": ActionCode("1040876951t", [], "AutoCast App", "", ""),
    "182s": ActionCode("", [], "Heart Rate", "", ""),
    "1830656901t": ActionCode("1040876951t", [], "AutoWear List Screens", "", ""),
    "1830829821t": ActionCode("1040876951t", [], "AutoWear 4 Screen", "", ""),
    "1831781712t": ActionCode("1040876951t", [], "AutoCast Settings", "", ""),
    "185s": ActionCode("", [], "Humidity", "", ""),
    "185t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "185"]],
            ["1", True, "Value", "0", ", Threshold="],
        ],
        "Filter Image",
        "52",
        "True",
    ),
    "1861978578e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoWear Command/Command Filter",
        "",
        "",
    ),
    "186700340e": ActionCode("1040876951t", [], "SecureTask", "", ""),
    "186s": ActionCode(
        "",
        [
            ["0", True, "", "0", ["Test=", "l", "235"]],
            ["1", True, "", "1", ", Name="],
            ["2", True, "", "1", ", Value="],
            ["3", True, "", "0", ["", "e", "Use Root"]],
            ["4", True, "", "1", ", Read Setting To="],
        ],
        "Custom Setting",
        "",
        "",
    ),
    "1879487834t": ActionCode("1040876951t", [], "AutoLocation Geofences", "", ""),
    "187s": ActionCode("", [], "Room", "", ""),
    "187t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Image Quality", "0", ", Image Quality="],
            [
                "2",
                True,
                "Delete From Memory After",
                "3",
                ["e", ", Delete From Memory After"],
            ],
        ],
        "Save Image",
        "52",
        "True",
    ),
    "188s": ActionCode("", [], "Dark Mode", "", ""),
    "188t": ActionCode(
        "",
        [
            ["0", False, "Source", "4", "Source="],
            ["1", True, "Max Width Or Height", "0", ", Max Width or Height="],
            [
                "2",
                True,
                "Respect EXIF Orientation",
                "3",
                ["e", ", Respect EXIF Orientation"],
            ],
        ],
        "Load Image",
        "52",
        "True",
    ),
    "18927444e": ActionCode(
        "",
        [["3", True, "", "5", ["", "e", ", Structure Output (JSON, etc)"]]],
        "AutoApps Command",
        "",
        "",
    ),
    "189s": ActionCode("", [], "Reaching", "", ""),
    "189t": ActionCode(
        "",
        [
            ["0", True, "From Left (%)", "0", "From Left (%)="],
            ["1", True, "From Right (%)", "0", ", From Right (%)="],
            ["2", True, "From Top (%)", "0", ", From Top (%)="],
            ["3", True, "From Bottom (%)", "0", ", From Bottom (%)="],
        ],
        "Crop Image",
        "52",
        "True",
    ),
    "18t": ActionCode(
        "",
        [
            ["0", True, "App", "2", ["a", "", "App="]],
            ["1", True, "Use Root", "3", ["e", "Use Root"]],
        ],
        "Kill App",
        "15",
        "True",
    ),
    "190s": ActionCode("", [], "Any Sensor", "", ""),
    "190t": ActionCode(
        "",
        [["0", True, "Direction", "0", ["Direction=", "l", "190"]]],
        "Flip Image",
        "52",
        "True",
    ),
    "1910383148t": ActionCode("1040876951t", [], "AutoTools Regex", "", ""),
    "1912522764t": ActionCode("1040876951t", [], "AutoTools Toast", "", ""),
    "191971507t": ActionCode(
        "",
        [["3", True, "", "5", ["", "e", ", Structure Output (JSON, etc)"]]],
        "AutoWear ADB Wifi",
        "",
        "",
    ),
    "191s": ActionCode("", [], "Physical Activity", "", ""),
    "191t": ActionCode(
        "",
        [
            ["0", True, "Direction", "0", ["Direction=", "l", "191"]],
            ["1", True, "Degrees", "0", [", Degrees=", "l", "191a"]],
        ],
        "Rotate Image",
        "52",
        "True",
    ),
    "1928381944t": ActionCode("1040876951t", [], "AutoCast Control Media", "", ""),
    "192s": ActionCode(
        "",
        [["1", True, "", "5", "Device IDs/Names="]],
        "Matter Light (Experimental)",
        "",
        "",
    ),
    "192t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Direction=", "l", "192"]],
            ["1", False, "Sound", "1", ", Sound="],
            ["2", True, "Stream", "0", [", Stream=", "l", "171"]],
        ],
        "Play Ringtone",
        "65",
        "False",
    ),
    "193s": ActionCode("", [], "Matter Light", "", ""),
    "193t": ActionCode(
        "",
        [["0", True, "Width", "0", "Width="], ["1", True, "Height", "0", ", Height="]],
        "Resize Image",
        "52",
        "True",
    ),
    "194s": ActionCode("", [], "Work Profile", "", ""),
    "194t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Test", "0", [", Test=", "l", "194"]],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test Scene",
        "102",
        "True",
    ),
    "1957670352t": ActionCode("1040876951t", [], "AutoWear App", "", ""),
    "1957681000e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoInput Gesture",
        "",
        "",
    ),
    "195s": ActionCode("", [], "NFC Status", "", ""),
    "195t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Test", "0", [", Test=", "l", "195"]],
            ["3", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test Element",
        "102",
        "True",
    ),
    "196s": ActionCode("", [], "Data Usage", "", ""),
    "197s": ActionCode("", [], "Compass Orientation", "", ""),
    "197t": ActionCode("", [], "Developer Settings", "30", "False"),
    "198t": ActionCode("", [], "Device Info Settings", "30", "False"),
    "199558826t": ActionCode("1040876951t", [], "TouchTask Gestures", "", ""),
    "199t": ActionCode("", [], "Add Account Settings", "30", "False"),
    "2000e": ActionCode(
        "",
        [["0", True, "", "2", "Owner Application="], ["1", True, "", "1", ", Title="]],
        "Notification Click",
        "",
        "",
    ),
    "2003e": ActionCode("", [], "Missed Call", "", ""),
    "2005e": ActionCode("", [], "SMS Success", "", ""),
    "200t": ActionCode("", [], "All Settings", "30", "False"),
    "2010186613t": ActionCode(
        "1040876951t",
        [],
        "AutoSheets Delete Cell Content",
        "",
        "",
    ),
    "2010e": ActionCode("", [], "SMS Failure", "", ""),
    "201e": ActionCode(
        "",
        [
            ["0", True, "", "2", "App="],
            ["1", True, "", "1", ", URL="],
            ["2", True, "", "1", ", Texts="],
            ["3", True, "", "1", ", Extras="],
        ],
        "Assistance Request",
        "",
        "",
    ),
    "201t": ActionCode("", [], "Airplane Mode Settings", "30", "False"),
    "2022280279t": ActionCode("1040876951t", [], "AutoNotification Media", "", ""),
    "202t": ActionCode("", [], "APN Settings", "30", "False"),
    "203e": ActionCode(
        "",
        [["0", True, "", "1", ["Priority=", "l", "4s"]]],
        "Battery Changed",
        "",
        "",
    ),
    "203t": ActionCode("", [], "Date Settings", "30", "False"),
    "2041559229t": ActionCode("1040876951t", [], "AutoSpotify Playlists", "", ""),
    "2046367074t": ActionCode("1040876951t", [], "AutoNotification Cancel", "", ""),
    "204t": ActionCode("", [], "Internal Storage Settings", "30", "False"),
    "2050e": ActionCode("", [], "Quick Setting Clicked", "", ""),
    "2051074546t": ActionCode("1040876951t", [], "AutoSpotify Control Media", "", ""),
    "205e": ActionCode("", [], "Battery Full", "", ""),
    "2063919988t": ActionCode("1040876951t", [], "AutoTools System State", "", ""),
    "206e": ActionCode("", [], "Battery Overheating", "", ""),
    "206t": ActionCode("", [], "WIFI Settings", "30", "False"),
    "2075e": ActionCode(
        "",
        [
            ["0", True, "", "0", ["Type=", "l", "235"]],
            ["1", True, "", "1", ", Name="],
            ["2", True, "", "1", ", Value="],
        ],
        "Custom Setting",
        "",
        "",
    ),
    "2076e": ActionCode(
        "",
        [["0", True, "", "1", "ID="], ["1", True, "", "1", ", Content="]],
        "NFC Tag",
        "",
        "",
    ),
    "2077e": ActionCode("", [], "Secondary App Opened", "", ""),
    "2078e": ActionCode("", [["1", True, "", "5", "Package="]], "App Changed", "", ""),
    "2079e": ActionCode(
        "",
        [
            ["0", True, "", "0", ["Type=", "l", "2079e"]],
            ["1", True, "", "1", ", Additional Time="],
        ],
        "Volume Long Press",
        "",
        "",
    ),
    "2080e": ActionCode(
        "",
        [["1", True, "", "5", "Name="], ["2", True, "", "1", ", Address="]],
        "BT Connected",
        "",
        "",
    ),
    "2081e": ActionCode(
        "",
        [
            ["1", True, "", "5", "Track="],
            ["2", True, "", "1", ", Album="],
            ["3", True, "", "1", ", Artist"],
            ["4", True, "", "1", ", Package="],
            ["5", True, "", "1", [", Type=", "l", "2081e"]],
        ],
        "Music Track Changed",
        "",
        "",
    ),
    "2082e": ActionCode("", [], "Network Changed", "", ""),
    "2083e": ActionCode("", [], "Significant Motion", "", ""),
    "2084e": ActionCode("", [], "Alarm Changed", "", ""),
    "2085e": ActionCode(
        "",
        [
            ["1", True, "", "1", "Component="],
            ["2", True, "", "1", ", Filter="],
            ["3", True, "", "0", ["", "e", ", Grep Filter"]],
        ],
        "Logcat Entry",
        "",
        "",
    ),
    "2086e": ActionCode("", [], "Pick Up Gesture", "", ""),
    "2088e": ActionCode("", [], "Any Sensor", "", ""),
    "2089e": ActionCode(
        "",
        [
            ["1", True, "", "5", "Port="],
            ["2", True, "", "0", ", Method="],
            ["3", True, "", "1", ", Path="],
            ["4", True, "", "1", ", Quick Response"],
            ["5", True, "", "1", ", Timeout="],
            ["6", True, "", "0", ["", "e", ", Only On Wifi"]],
            ["7", True, "", "0", ", Network Name/MAC Address="],
        ],
        "HTTP Request",
        "",
        "",
    ),
    "208e": ActionCode(
        "",
        [["0", True, "", "1", ["Priority=", "l", "4s"]]],
        "Display On",
        "",
        "",
    ),
    "208t": ActionCode("", [], "Location Settings", "30", "False"),
    "2090e": ActionCode("", [], "Physical Activity", "", ""),
    "2091e": ActionCode(
        "",
        [
            ["1", True, "", "1", "Component="],
            ["2", True, "", "1", ", Variables="],
            ["3", True, "", "0", ["", "e", ", Last Variable Is Array"]],
        ],
        "Command",
        "",
        "",
    ),
    "2092e": ActionCode("", [], "Power Menu Shown", "", ""),
    "2093e": ActionCode(
        "",
        [["0", True, "", "2", "Command="]],
        "Assistant Action",
        "",
        "",
    ),
    "2094e": ActionCode("", [], "Call Screened", "", ""),
    "2095e": ActionCode("", [["1", True, "", "5", "Interval (ms)="]], "Tick", "", ""),
    "2096e": ActionCode(
        "",
        [
            ["1", True, "", "5", "Minimum Confidence="],
            ["2", True, "", "0", ", Maximum Light="],
            ["3", True, "", "0", ", Maximum Motion="],
        ],
        "Sleeping",
        "",
        "",
    ),
    "2097e": ActionCode(
        "",
        [["1", True, "", "5", ["", "e", "Ignore Set By Tasker"]]],
        "Clipboard Changed",
        "",
        "",
    ),
    "2098e": ActionCode("", [], "Accessibility Services Changed", "", ""),
    "2099e": ActionCode("", [], "Device Unlock Failed", "", ""),
    "20t": ActionCode(
        "",
        [
            ["0", True, "Package/App Name", "2", ["a", "", "App="]],
            ["1", False, "Data", "1", ", Data="],
            [
                "2",
                True,
                "Exclude From Recent Apps",
                "3",
                ["e", "Exclude From Recent Apps"],
            ],
            ["3", True, "Always Start New Copy", "3", ["e", "Always Start New Copy"]],
        ],
        "Launch App",
        "15",
        "True",
    ),
    "2100e": ActionCode("", [], "Remote Action Token Changed", "", ""),
    "2101e": ActionCode(
        "",
        [
            ["0", False, "", "5", ""],
            ["1", False, "", "1", ", Package Name"],
            ["2", False, "", "1", ", Share Trigger"],
            ["3", False, "", "1", ", Subject"],
            ["4", False, "", "1", ", Text"],
            ["5", False, "", "1", ", Files"],
            ["6", False, "", "1", ", Mime Type"],
            ["7", False, "", "1", ", Action"],
            ["8", False, "", "1", ", Category"],
        ],
        "Received Share",
        "",
        "",
    ),
    "2102e": ActionCode(
        "",
        [
            ["0", False, "", "5", ""],
            ["1", False, "", "0", ["e", "Added"]],
            ["2", False, "", "0", ["e", "Updated"]],
            ["3", False, "", "0", ["e", "Deleted"]],
            ["4", False, "", "0", ["e", "Other"]],
        ],
        "Calendar Changed",
        "",
        "",
    ),
    "210e": ActionCode(
        "",
        [["0", True, "", "1", ["Priority=", "l", "4s"]]],
        "Display Off",
        "",
        "",
    ),
    "210t": ActionCode("", [], "InputMethod Settings", "30", "False"),
    "2114100406t": ActionCode("1040876951t", [], "AutoLaunch Query", "", ""),
    "211707263t": ActionCode("1040876951t", [], "Global Actions", "", ""),
    "211905330t": ActionCode("1040876951t", [], "AutoContacts", "", ""),
    "211t": ActionCode("", [], "Sync Settings", "30", "False"),
    "2123721228e": ActionCode("", [], "AutoTools Assistant", "", ""),
    "2124887619t": ActionCode("1040876951t", [], "AutoTools OCR", "", ""),
    "212t": ActionCode("", [], "WIFI IP Settings", "30", "False"),
    "2132875086t": ActionCode(
        "1040876951t",
        [],
        "AutoSheets Delete Rows/Columns",
        "",
        "",
    ),
    "2142731215t": ActionCode("1040876951t", [], "AutoSheets Duplicate Sheet", "", ""),
    "214t": ActionCode("", [], "Wireless Settings", "30", "False"),
    "215e": ActionCode("", [], "Button: Camera", "", ""),
    "216e": ActionCode("", [], "Button: Long Search", "", ""),
    "216t": ActionCode(
        "",
        [["0", False, "App", "1", "App"]],
        "App Settings",
        "30",
        "False",
    ),
    "218t": ActionCode("", [], "Bluetooth Settings", "30", "False"),
    "219t": ActionCode("", [], "Quick Settings", "30", "True"),
    "220e": ActionCode("", [], "File Moved", "", ""),
    "220t": ActionCode("", [], "Mobile Data Settings", "30", "False"),
    "222e": ActionCode(
        "",
        [["0", True, ", File", "1", "File="], ["1", True, "Event", "1", ", Event="]],
        "File Modified",
        "",
        "",
    ),
    "222t": ActionCode("", [], "Display Settings", "30", "False"),
    "224e": ActionCode("", [], "File Closed", "", ""),
    "224t": ActionCode("", [], "Locale Settings", "30", "False"),
    "226e": ActionCode("", [], "File Opened", "", ""),
    "226t": ActionCode("", [], "App Manage Settings", "30", "False"),
    "227t": ActionCode("", [], "Memory Card Settings", "30", "False"),
    "228e": ActionCode("", [], "File Deleted", "", ""),
    "228t": ActionCode("", [], "Network Operator Settings", "30", "False"),
    "229t": ActionCode("", [], "Quick Launch Settings", "30", "False"),
    "22t": ActionCode("", [], "Load Last App", "15", "True"),
    "230e": ActionCode("", [], "File Attribute Change", "", ""),
    "230t": ActionCode("", [], "Security Settings", "30", "False"),
    "231t": ActionCode("", [], "Search Settings", "30", "False"),
    "232t": ActionCode("", [], "Sound Settings", "30", "False"),
    "234244923t": ActionCode("1040876951t", [], "AutoInput Unlock Screen", "", ""),
    "234t": ActionCode("", [], "Dictionary Settings", "30", "False"),
    "235t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Test=", "l", "235"]],
            ["1", True, "Name", "1", ", Name="],
            ["2", False, "Value", "1", ", Value="],
            ["3", True, "Use Root", "3", ["e", "Use Root"]],
            ["4", False, "Read Setting To", "1", ", Read Setting To="],
        ],
        "Custom Setting",
        "30",
        "True",
    ),
    "236t": ActionCode("", [], "Accessibility Settings", "30", "False"),
    "237t": ActionCode("", [], "Notification Listener Settings", "30", "False"),
    "238t": ActionCode("", [], "Privacy Settings", "30", "False"),
    "239t": ActionCode("", [], "Print Settings", "30", "False"),
    "24081025t": ActionCode("1040876951t", [], "AutoNotification Snooze", "", ""),
    "244t": ActionCode("", [], "Toggle Split Screen", "15", "True"),
    "245t": ActionCode("", [], "Back Button", "55", "True"),
    "246t": ActionCode("", [], "Long Power Button", "55", "True"),
    "247t": ActionCode("", [], "Show Recents", "15", "True"),
    "248t": ActionCode(
        "",
        [["0", True, "Dim", "3", "File="], ["1", True, "Lock", "3", ["e", "Dim"]]],
        "Turn Off",
        "40",
        "True",
    ),
    "249t": ActionCode("", [], "System Screenshot", "55", "True"),
    "250t": ActionCode(
        "",
        [
            ["0", False, "Recipient(s)", "1", "Recipient(s)="],
            ["1", False, "Message", "1", "Message="],
        ],
        "Compose SMS",
        "90",
        "False",
    ),
    "251t": ActionCode("", [], "Battery Settings", "30", "False"),
    "252t": ActionCode(
        "",
        [["0", True, "App", "2", "App="]],
        "Set SMS App",
        "90",
        "False",
    ),
    "254t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Speakerphone",
        "20",
        "False",
    ),
    "256t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Vibrate On Ringer",
        "20",
        "False",
    ),
    "257t": ActionCode("", [], "Power Usage Settings", "30", "False"),
    "258t": ActionCode(
        "",
        [["0", True, "Set", "3", "Set"]],
        "Vibrate On Notify",
        "20",
        "False",
    ),
    "259t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Notification Pulse",
        "20",
        "False",
    ),
    "25t": ActionCode(
        "",
        [["0", True, "Page", "0", "Page"], ["1", False, "Package", "1", "Package"]],
        "Go Home",
        "15",
        "False",
    ),
    "260559060t": ActionCode("1040876951t", [], "AutoNotification Block", "", ""),
    "263029931t": ActionCode("1040876951t", [], "AutoInput Unlock Screen", "", ""),
    "268157305t": ActionCode("1040876951t", [], "AutoNotification Tiles", "", ""),
    "294t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Bluetooth",
        "80",
        "True",
    ),
    "295t": ActionCode(
        "",
        [["0", True, "Name", "1", "Name="]],
        "Bluetooth ID",
        "80",
        "False",
    ),
    "296t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Bluetooth Voice",
        "90",
        "False",
    ),
    "2e": ActionCode("", [], "Phone Offhook", "", ""),
    "2s": ActionCode(
        "",
        [["0", True, "", "0", ["Status=", "l", "switch_set"]]],
        "BT Status",
        "",
        "",
    ),
    "3000e": ActionCode("", [], "Gesture", "", ""),
    "3001e": ActionCode(
        "",
        [
            ["0", True, "", "0", ["Axis=", "l", "3001e"]],
            ["1", True, "", "0", ["Sensitivity=", "l", "3001ea"]],
            ["2", True, "", "0", ["Duration=", "l", "3001eb"]],
        ],
        "Shake",
        "",
        "",
    ),
    "300e": ActionCode("", [], "Date Set", "", ""),
    "300t": ActionCode("", [], "Anchor", "105", "False"),
    "301t": ActionCode("", [["0", True, "Set", "3", "Set"]], "Mic Mute", "20", "False"),
    "302e": ActionCode("", [], "Time/Date Set", "", ""),
    "303e": ActionCode("", [], "Timer Change", "", ""),
    "303t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "Alarm Volume",
        "20",
        "False",
    ),
    "304e": ActionCode("", [], "Timezone Set", "", ""),
    "304t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "Ringer Volume",
        "20",
        "False",
    ),
    "3050e": ActionCode(
        "",
        [
            ["0", True, "", "1", ", Variable="],
            ["1", True, "", "1", ", Value="],
            ["2", True, "", "0", ["", "e", ", User Variables Only"]],
        ],
        "Variable Set",
        "",
        "",
    ),
    "305e": ActionCode("", [], "Alarm Clock", "", ""),
    "305t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "Notification Volume",
        "20",
        "False",
    ),
    "3060e": ActionCode("", [], "Variable Cleared", "", ""),
    "306e": ActionCode("", [], "Alarm Done", "", ""),
    "306t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level"],
            ["1", True, "Display", "3", "Display"],
            ["2", True, "Sound", "3", "Sound"],
        ],
        "In-Call Volume",
        "20",
        "False",
    ),
    "3071e": ActionCode("", [], "Zoom Click", "", ""),
    "307e": ActionCode("", [], "Monitor Start", "", ""),
    "307t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "Media Volume",
        "20",
        "False",
    ),
    "308t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "System Volume",
        "20",
        "False",
    ),
    "309e": ActionCode("", [], "Steps Taken", "", ""),
    "309t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level"],
            ["1", True, "Display", "3", "Display"],
            ["2", True, "Sound", "3", "Sound"],
        ],
        "DTMF Volume",
        "20",
        "False",
    ),
    "30s": ActionCode(
        "",
        [["0", True, "", "0", ["Type=", "l", "30s"]]],
        "Headset Plugged",
        "",
        "",
    ),
    "30t": ActionCode(
        "",
        [
            ["0", True, "MS", "0", "MS="],
            ["1", True, "Seconds", "0", ", Seconds="],
            ["2", True, "Minutes", "0", ", Minutes="],
            ["3", True, "Hours", "0", ", Hours="],
            ["4", True, "Days", "0", ", Days="],
        ],
        "Wait",
        "105",
        "True",
    ),
    "310t": ActionCode(
        "",
        [["0", True, "Mode", "0", ["Mode=", "l", "310"]]],
        "Silent Mode",
        "20",
        "False",
    ),
    "311t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "BT Voice Volume",
        "20",
        "False",
    ),
    "312t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "312"]],
            ["1", True, "Allow Callers", "0", "Allow Callers"],
            ["2", True, "Allow Repeat Callers", "3", "Allow Repeat Callers"],
            ["3", True, "Allow SMS Senders", "0", "Allow SMS Senders"],
            ["4", False, "Allow Categories", "1", "Allow Categories"],
            ["5", False, "Suppressed Effects", "1", "Suppressed Effects"],
            ["6", True, "Output Variables", "5", "Output Variables"],
        ],
        "Interrupt Mode",
        "20",
        "True",
    ),
    "313t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "313"]],
            ["1", True, "Ignore DND", "3", ["e", ", Ignore DND"]],
        ],
        "Sound Mode",
        "20",
        "False",
    ),
    "314t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "314"]],
            ["1", True, "Title", "1", ", Title="],
            ["2", False, "Subtitle", "1", ", Subtitle="],
            ["3", False, "Description", "1", ", Description="],
            ["4", False, "Cancel Button Text", "1", ", Cancel Button Text="],
            ["5", True, "Number Of Attempts", "0", ", Number of Attempts="],
            ["6", False, "Read Result To", "1", ", Read Result Into="],
            ["7", True, "Timeout (Seconds)", "0", ", Timeout (Seconds)="],
            ["8", True, "Confirmation Required", "3", ["e", ", Confirmation Required"]],
            [
                "9",
                True,
                "Device Credentials Allowed",
                "3",
                ["e", ", Device Credentials Allowed"],
            ],
        ],
        "Authentication Dialog",
        "55",
        "True",
    ),
    "316t": ActionCode(
        "",
        [
            ["0", True, "Size", "0", ["Size=", "l", "316"]],
            ["1", False, "Manual", "1", ", Manual="],
        ],
        "Display Size",
        "40",
        "True",
    ),
    "317t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Output Variables", "5", "Output Variables"],
        ],
        "NFC",
        "80",
        "True",
    ),
    "318t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "318"]],
            [
                "1",
                True,
                "Alternative Method (Check Help)",
                "3",
                ["e", ", Alternative Method (Check Help)"],
            ],
        ],
        "Force Rotation",
        "40",
        "True",
    ),
    "319692633t": ActionCode("1040876951t", [], "AutoShare Process Text", "", ""),
    "319t": ActionCode(
        "",
        [
            ["0", True, "Required Permissions", "1", "Required Permissions="],
            ["1", False, "Prompt If Not Granted", "1", ", Prompt If Not Granted="],
        ],
        "Ask Permissions",
        "104",
        "True",
    ),
    "320t": ActionCode(
        "",
        [
            ["0", True, "Host", "1", ", Host="],
            ["1", True, "Number", "0", ", Number="],
            ["2", False, "Average Result Variable", "1", ", Average Result Variable="],
            ["3", False, "Min Result Variable", "1", ", Min Result Variable="],
            ["4", False, "Max Result Variable", "1", ", Max Result Variable="],
        ],
        "Ping",
        "80",
        "True",
    ),
    "321t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Google Drive Account", "1", "Google Drive/Account="],
            ["2", True, "Data / File", "1", ", Data/File="],
            ["3", False, "Remote File Name", "1", ", Remote File Name="],
            ["4", False, "Remote Folder", "1", ", Remote Folder="],
            ["5", False, "Content Description", "1", ", Content Description="],
            ["6", True, "Overwrite If Exists", "3", ["e", ", Overwrite If Exists"]],
            ["7", True, "Publicly Share File", "3", ["e", ", Publicly Share File"]],
            ["8", False, "Mime Type", "1", ", Mime Type="],
        ],
        "GD Upload",
        "51",
        "True",
    ),
    "322t": ActionCode(
        "",
        [
            ["0", True, "Path", "1", "Path="],
            ["1", False, "Google Drive Account", "1", ", Google Drive Account="],
            [
                "2",
                True,
                "Include User Vars/Prefs",
                "3",
                ["e", ", Include User Vars/Prefs"],
            ],
        ],
        "Data Backup",
        "110",
        "True",
    ),
    "323t": ActionCode(
        "",
        [
            ["0", True, "Bluetooth", "3", ["e", "Bluetooth"]],
            ["1", True, "Cell", "3", ["e", ", Cell"]],
            ["2", True, "NFC", "3", ["e", ", NFC"]],
            ["3", True, "Wifi", "3", ["e", ", Wifi"]],
            ["4", True, "Wimax", "3", ["e", ", Wimax"]],
        ],
        "Airplane Radios",
        "80",
        "False",
    ),
    "324t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Google Drive Account", "1", "Google Drive Account="],
            ["2", True, "Type", "0", [", Type=", "l", "324"]],
            ["3", True, "Files or Folders", "0", [", Files or Folders=", "l", "324a"]],
            ["4", False, "Remote Folder", "1", "Remote Folder"],
            ["5", True, "Query", "1", ", Query="],
        ],
        "GD List",
        "51",
        "True",
    ),
    "325t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Google Drive Account", "1", "Google Drive Account="],
            ["2", True, "Trash Value", "0", [", Trash Value=", "l", "325"]],
            ["3", True, "Type", "0", [", Type=", "l", "325a"]],
            ["4", True, "File Id", "1", ", File ID="],
            ["5", True, "Remote Folder", "1", ", Path="],
            ["6", False, "Remote File Name", "1", ", Remote File Name="],
            ["7", True, "Remote Name", "1", "Remote Name"],
        ],
        "GD Trash",
        "51",
        "True",
    ),
    "326t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Google Drive Account", "1", "Google Drive Account="],
            ["2", True, "Type", "0", [", Type=", "l", "325a"]],
            ["3", True, "File Id", "1", ", File ID="],
            ["4", False, "Remote Folder", "1", ", Remote Folder="],
            ["5", False, "Remote File Name", "1", ", Remote File Name="],
            ["6", True, "Local Path", "1", ", Local Path="],
        ],
        "GD Download",
        "51",
        "True",
    ),
    "327t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Google Drive Account", "1", "Google Drive Account="],
            ["2", True, "Full Access", "3", ["e", ", Full Access"]],
        ],
        "GD Sign In",
        "51",
        "True",
    ),
    "328t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Input", "1", "Input"],
            ["2", True, "Time Between Inputs", "0", ", Time Between Inputs="],
            [
                "3",
                True,
                "Don't Restore Keyboard",
                "3",
                ["e", ", Don't Restore Keyboard"],
            ],
        ],
        "Keyboard",
        "55",
        "True",
    ),
    "329t": ActionCode(
        "",
        [
            ["0", False, "Left", "1", "Left="],
            ["1", False, "Center", "1", "Center="],
            ["2", False, "Right", "1", "Right="],
        ],
        "Navigation Bar",
        "55",
        "True",
    ),
    "330t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Payload To Write", "1", "Payload To Write="],
            ["2", False, "Payload Type", "1", ", Payload Type="],
        ],
        "NFC Tag",
        "80",
        "True",
    ),
    "331t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Auto-Sync",
        "80",
        "False",
    ),
    "332t": ActionCode("", [["0", True, "Set", "3", "Set"]], "GPS", "60", "True"),
    "333t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Output Variables", "5", "Output Variables"],
        ],
        "Airplane Mode",
        "80",
        "True",
    ),
    "334t": ActionCode(
        "",
        [
            ["0", True, "Text/SSML", "1", "Test/SSML="],
            ["1", True, "Voice", "1", ", Voice="],
            ["2", True, "Stream", "0", [", Type=", "l", "171"]],
            ["3", True, "Pitch", "0", ", Pitch="],
            ["4", True, "Speed", "0", ", Speed="],
            [
                "5",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
            ["6", False, "File", "1", ", File="],
            ["7", False, "Override API Key", "1", ", Override API Key="],
            ["8", True, "Respect Audio Focus", "3", "Respect Audio Focus"],
        ],
        "Say WaveNet",
        "10",
        "True",
    ),
    "335t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Package/App Name", "1", "Package/App Name="],
            ["2", False, "Ignore Packages", "1", ", Ignore Packages="],
            [
                "3",
                True,
                "Ignore Unlaunchable Apps",
                "3",
                ["e", ", Ignore Unlaunchable Apps"],
            ],
            ["4", True, "Get All Details", "3", ["e", ", Get All Details"]],
        ],
        "App Info",
        "15",
        "True",
    ),
    "337t": ActionCode(
        "",
        [
            ["0", False, "Package", "1", "Package="],
            ["1", False, "Category", "1", ", Category="],
        ],
        "Notification Settings",
        "30",
        "False",
    ),
    "338t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Category", "1", "Category="],
        ],
        "Notification Category Info",
        "30",
        "True",
    ),
    "339t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Method", "0", ["Method=", "l", "339"]],
            ["2", True, "URL", "1", ", URL="],
            ["3", False, "Headers", "1", ", Headers="],
            ["4", False, "Query Parameters", "1", ", Query Parameters="],
            ["5", False, "Body", "1", ", Body="],
            ["6", False, "File To Send", "1", ", File To Send="],
            [
                "7",
                False,
                "File/Directory To Save With Output",
                "1",
                ", File/Directory To Save With Output=",
            ],
            ["8", True, "Timeout (Seconds)", "0", ", Timeout="],
            ["9", True, "Trust Any Certificate", "3", ["e", ", Trust Any Certificate"]],
            [
                "10",
                True,
                "Automatically Follow Redirects",
                "3",
                ["e", ", Automatically Follow Redirects"],
            ],
            ["11", True, "Use Cookies", "3", ["e", ", Use Cookies"]],
            [
                "12",
                True,
                "Structure Output (JSON, etc)",
                "3",
                ["e", ", Structure Output (JSON, etc)"],
            ],
        ],
        "HTTP Request",
        "80",
        "True",
    ),
    "340t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Action", "0", ["Action=", "l", "340"]],
            ["2", True, "Device", "1", ", Device="],
            ["3", True, "Timeout (Seconds)", "0", ", Timeout="],
        ],
        "Bluetooth Connection",
        "80",
        "True",
    ),
    "341t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "341"]],
            ["1", True, "Data", "1", "Data"],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test Net",
        "80",
        "True",
    ),
    "342t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "342"]],
            ["1", True, "Data", "1", ", Data="],
            ["2", True, "Store Result In", "1", ", Store Result In="],
            ["3", True, "Use Root", "3", ["e", ", Use Root"]],
            ["4", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Test File",
        "50",
        "True",
    ),
    "343t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "343"]],
            ["1", True, "Data", "1", ", Data="],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test Media",
        "65",
        "True",
    ),
    "344636446t": ActionCode(
        "1040876951t",
        [],
        "AutoVoice Trigger Alexa Routine",
        "",
        "",
    ),
    "344t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "344"]],
            ["1", True, "Data", "1", ", Data="],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test App",
        "15",
        "True",
    ),
    "345t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "345"]],
            ["1", True, "Data", "1", ", Data="],
            ["2", True, "Store Result In", "1", ", Store Results In="],
        ],
        "Test Variable",
        "120",
        "True",
    ),
    "346t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "346"]],
            ["1", True, "Data", "1", ", Data="],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test Phone",
        "90",
        "True",
    ),
    "347t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "347"]],
            ["1", True, "Data", "1", ", Data="],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "Test Tasker",
        "110",
        "False",
    ),
    "34829087e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "Tools & AmazFit",
        "",
        "",
    ),
    "348t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "348"]],
            ["1", True, "Data", "1", ", Store Result In="],
            ["2", True, "Store Result In", "1", "Store Result In"],
        ],
        "Test Display",
        "40",
        "False",
    ),
    "349t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "349"]],
            ["1", True, "Data", "1", ", Store Result In="],
            ["2", True, "Store Result In", "1", "Store Result In"],
        ],
        "Test System",
        "104",
        "False",
    ),
    "351t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Method", "0", ["Method=", "l", "351"]],
            ["2", True, "Client ID", "1", ", Client ID="],
            ["3", True, "Client Secret", "1", ", Client Secret="],
            ["4", True, "Endpoint To Get Code", "1", ", Endpoint To Get Code="],
            [
                "5",
                True,
                "Endpoint To Get Refresh Token",
                "1",
                ", Endpoint To Get Refresh Token=",
            ],
            ["6", False, "Scopes", "1", ", Scopes="],
            [
                "7",
                True,
                "Force Re-Authentication",
                "3",
                ["e", "Force Re-Authentication"],
            ],
            ["8", True, "Timeout (Seconds)", "0", ", Timeout="],
            ["9", True, "Username", "1", ", Username="],
            ["10", True, "Password", "1", ", Password="],
        ],
        "HTTP Auth",
        "80",
        "True",
    ),
    "352t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Network Type", "0", ["Network Type=", "l", "352"]],
            ["2", True, "From", "1", ", From="],
            ["3", True, "To", "1", ", To="],
            ["4", False, "Package", "1", ", Package="],
            ["5", False, "SIM Card", "1", "SIM Card"],
        ],
        "Get Network Data Usage",
        "80",
        "True",
    ),
    "354t": ActionCode(
        "",
        [
            ["0", True, "Variable Array", "1", "Variable Array="],
            ["1", True, "Values", "1", ", Values="],
            ["2", False, "Splitter", "1", ", Splitter="],
        ],
        "Array Set",
        "120",
        "True",
    ),
    "355t": ActionCode(
        "",
        [
            ["0", True, "Variable Array", "1", "Variable Array="],
            ["1", True, "Position", "0", ", Position="],
            ["2", True, "Value", "1", ", Value="],
            ["3", True, "Fill Spaces", "3", ["e", ", Fill Spaces"]],
        ],
        "Array Push",
        "120",
        "False",
    ),
    "356t": ActionCode(
        "",
        [
            ["0", True, "Variable Array", "1", "Variable Array="],
            ["1", True, "Position", "0", ", Position="],
            ["2", False, "To Var", "1", ", To Var="],
        ],
        "Array Pop",
        "120",
        "False",
    ),
    "357t": ActionCode(
        "",
        [["0", True, "Variable Array", "1", "Variable Array="]],
        "Array Clear",
        "120",
        "False",
    ),
    "358t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Type", "0", ["Type=", "l", "358"]],
            ["2", True, "Device", "1", ", Device="],
            ["3", True, "Timeout (Seconds)", "0", ", Timeout="],
        ],
        "Bluetooth Info",
        "80",
        "True",
    ),
    "35t": ActionCode(
        "",
        [
            ["0", True, "MS", "0", ["if"]],
            ["1", True, "Seconds", "0", "MS="],
            ["2", True, "Minutes", "0", ", Seconds="],
            ["3", True, "Hours", "0", ", Minutes="],
            ["4", True, "Days", "0", ", Hours="],
        ],
        "Wait Until",
        "105",
        "False",
    ),
    "360t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Title", "1", "Title="],
            ["2", False, "Text", "1", ", Text="],
            ["3", False, "Default Input", "1", ", Default Input="],
            ["4", True, "Close After (Seconds)", "0", ", Close After (Seconds)="],
            ["5", False, "Input Type", "1", ", Input Type="],
            ["6", True, "Use HTML", "3", ["e", ", Use HTML"]],
            ["7", True, "Pre-Select Input", "3", ["e", ", Pre-Select Input"]],
            ["8", False, "Output Variable Name", "1", "Output Variable Name"],
        ],
        "Input Dialog",
        "55",
        "True",
    ),
    "361t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Output Variables", "5", "Output Variables"],
        ],
        "Dark Mode",
        "40",
        "True",
    ),
    "362t": ActionCode(
        "",
        [["0", True, "Assistant", "1", "Assistant="]],
        "Set Assistant",
        "104",
        "True",
    ),
    "363t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Set=", "l", "switch_set"]],
            ["1", False, "SIM Card", "1", "SIM Card"],
        ],
        "Mobile Network Type",
        "80",
        "True",
    ),
    "364t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Minutes Difference", "0", "Minutes Difference="],
        ],
        "Test Next Alarm",
        "104",
        "True",
    ),
    "365t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Function", "1", "Function="],
        ],
        "Tasker Function",
        "110",
        "True",
    ),
    "366t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Timeout (Seconds)", "0", "Timeout (Seconds)="],
            [
                "2",
                False,
                "Minimum Accuracy (meters)",
                "1",
                ", Minimum Accuracy (meters)=",
            ],
            ["3", False, "Speed (meters/second)", "1", ", Speed (meters/second)="],
            ["4", False, "Altitude (meters)", "1", ", Altitude (meters)="],
            ["5", False, "Near Location", "1", ", Near Location="],
            [
                "6",
                True,
                "Enable Location If Needed",
                "3",
                ["e", ", Enable Location If Needed"],
            ],
            [
                "7",
                True,
                "Last Location If Timeout",
                "3",
                ["e", ", Last Location If Timeout"],
            ],
            [
                "8",
                False,
                "Min Speed Accuracy (m/s)",
                "1",
                ", Min Speed Accuracy (m/s)=",
            ],
            ["9", True, "Force High Accuracy", "3", ["e", ", Force High Accuracy"]],
        ],
        "Get Location v2",
        "60",
        "True",
    ),
    "367t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Output Variables", "5", "Output Variables"],
        ],
        "Camera",
        "15",
        "True",
    ),
    "368t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Title", "1", "Title="],
            ["2", True, "Select Radius", "3", ["e", ", Select Radius"]],
            ["3", False, "Initial Location", "1", ", Initial Location="],
            ["4", True, "Type", "0", [", Set=", "l", "368"]],
        ],
        "Pick Location",
        "60",
        "True",
    ),
    "369t": ActionCode(
        "",
        [
            ["0", True, "Variable Array", "1", "Variable Array="],
            ["1", True, "Type", "0", [", Type=", "l", "369"]],
        ],
        "Array Process",
        "120",
        "False",
    ),
    "370t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Shortcut="],
            ["1", True, "Shortcut", "1", "Shortcut"],
        ],
        "Shortcut",
        "15",
        "True",
    ),
    "371t": ActionCode("", [["0", True, "Cmd", "0", "Cmd"]], "Astrid", "130", "False"),
    "372t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Type", "1", "Type="],
        ],
        "Sensor Info",
        "104",
        "True",
    ),
    "373t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Type", "1", "Type="],
            ["2", True, "Timeout (Seconds)", "0", ", Timeout (Seconds)="],
            ["3", True, "Convert Orientation", "3", ["e", ", Convert Orientation"]],
        ],
        "Test Sensor",
        "104",
        "True",
    ),
    "374t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Mode", "0", ["Type=", "l", "374"]],
            ["2", True, "Output File", "1", ", Output File="],
            ["3", True, "Sound", "3", ["e", ", Sound"]],
            ["4", False, "Video Encoder", "1", ", Video Encoder="],
            ["5", False, "Resolution", "1", ", Resolution="],
            ["6", False, "Video Bitrate", "1", ", Video Bitrate="],
            ["7", False, "Video Framerate", "1", "Video Framerate"],
        ],
        "Screen Capture",
        "40",
        "True",
    ),
    "375t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Command", "1", "Command"],
            ["2", False, "Host", "1", "Host"],
            ["3", False, "Port", "1", "Port"],
            ["4", True, "Timeout (Seconds)", "0", "Timeout (Seconds)"],
            [
                "5",
                True,
                "Enable Debugging (Check Help)",
                "3",
                "Enable Debugging (Check Help)",
            ],
            ["6", False, "Result Encoding", "1", "Result Encoding"],
        ],
        "ADB Wifi",
        "35",
        "True",
    ),
    "376t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", False, "Mime Type", "1", ", Mime Type="],
            ["2", True, "Show Chooser Dialog", "3", ["e", ", Show Chooser Dialog"]],
            ["3", False, "Chooser Dialog Title", "1", ", Chooser Dialog Title="],
        ],
        "Share File",
        "50",
        "True",
    ),
    "377t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Title", "1", "Title="],
            ["2", False, "Text", "1", ", Text="],
            ["3", False, "Button 1", "1", ", Button 1="],
            ["4", False, "Button 2", "1", ", Button 2="],
            ["5", False, "Button 3", "1", ", Button 3="],
            ["6", True, "Close After (Seconds)", "0", ", Close After (Seconds)="],
            ["7", True, "Use HTML", "3", ["e", ", Use HTML"]],
            ["8", False, "Image", "1", ", Image="],
            ["9", False, "Max Width Or Height", "1", ", Max Width or Height="],
        ],
        "Text/Image Dialog",
        "55",
        "True",
    ),
    "378t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Mode", "0", ["Mode=", "l", "378"]],
            ["2", True, "Title", "1", ", Title="],
            ["3", True, "Items", "1", ", Items="],
            ["4", False, "Selected Items", "1", ", Long Click Task="],
            ["5", False, "Long Click Task", "1", "Long Click Task"],
            ["6", False, "Button 1", "1", ", Button 1="],
            ["7", False, "Button 2", "1", ", Button 2="],
            ["8", False, "Button 3", "1", ", Button 3="],
            ["9", True, "Close After (Seconds)", "0", ", Close After (Seconds)="],
            ["10", True, "Use HTML", "3", ["e", ", Use HTML"]],
            ["11", True, "First Visible Index", "0", ", First Visible Index="],
            ["12", True, "Hide Filter", "3", ["e", ", Hide Filter"]],
            ["13", False, "Text", "1", ", Text="],
        ],
        "List Dialog",
        "55",
        "True",
    ),
    "379t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Action", "0", ["Action=", "l", "379"]],
            ["2", True, "Package/App Name", "2", ", App="],
            ["3", True, "Function", "1", ", Function="],
            ["4", True, "Enable", "3", ["e", ", Enable"]],
            ["5", False, "User Restrictions", "1", ", Restrictions="],
            ["6", False, "Permission", "1", "Permission"],
        ],
        "Device Admin/Owner",
        "104",
        "True",
    ),
    "37s": ActionCode("", [], "Variable Set", "", ""),
    "37t": ActionCode("", [], "If", "105", "False"),
    "380t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Request ID", "1", "Request ID="],
            ["2", True, "Status Code", "1", ", Status Code="],
            ["3", False, "Headers", "1", ", Headers="],
            ["4", True, "Type", "0", ["Type=", "l", "380"]],
            ["5", False, "Body", "1", ""],
            ["6", True, "File", "1", ", File="],
            ["7", False, "Mime Type", "1", ", Mime Type="],
            ["8", True, "File Inline", "3", ["e", ", File Inline"]],
            ["9", True, "URL", "1", "URL"],
        ],
        "HTTP Response",
        "80",
        "True",
    ),
    "381t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Contact="],
            ["1", False, "Contact", "1", ", App="],
            ["2", False, "App", "1", "App"],
            ["3", False, "Text", "1", "Text"],
            ["4", True, "Back Out", "3", "Back Out"],
        ],
        "Contact Via App",
        "90",
        "True",
    ),
    "383t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Contact=", "l", "383"]],
            ["1", True, "Continue Task Immediately", "3", "Continue Task Immediately"],
        ],
        "Settings Panel",
        "30",
        "False",
    ),
    "384t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "ID", "1", "ID="],
            ["2", True, "Action", "0", [", Action=", "l", "384"]],
            ["3", True, "Type", "0", [", Type=", "l", "384a"]],
            ["4", True, "Title", "1", ", Title="],
            ["5", False, "Subtitle", "1", ", Subtitle="],
            ["6", False, "Icon", "1", ", Icon="],
            ["7", False, "Command", "1", ", Command="],
            ["8", False, "Active", "1", ", Active="],
            ["9", False, "Range Min", "1", ", Range Min="],
            ["10", False, "Range Max", "1", ", Range Max="],
            ["11", False, "Range Current", "1", ", Range Current="],
            ["12", False, "Range Step", "1", "Range Step="],
            ["13", False, "Range Format", "1", ", Range Format="],
            [
                "14",
                True,
                "Can Use On Locked Device",
                "3",
                ["e", ", Can Use On Locked Device"],
            ],
        ],
        "Device Control (Power Menu Action)",
        "55",
        "True",
    ),
    "385t": ActionCode(
        "",
        [["0", True, "Command", "1", "Command="]],
        "Command",
        "110",
        "True",
    ),
    "386t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ["ID=", "l", "386"]],
            ["1", True, "Disallow/Allow", "0", ["e", ", Skip Call Log"]],
            ["2", True, "Reject", "3", ["e", ", Skip Notification"]],
            ["3", True, "Silence", "3", "Silence"],
            ["4", True, "Skip Call Log", "3", "Skip Call Log"],
            ["5", True, "Skip Notification", "3", "Skip Notification"],
        ],
        "Call Screening",
        "90",
        "True",
    ),
    "387t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Display", "3", ["e", ", Display"]],
            ["2", True, "Sound", "3", ["e", ", Sound"]],
        ],
        "Accessibility Volume",
        "20",
        "True",
    ),
    "388543774t": ActionCode(
        "1040876951t",
        [],
        "AutoSheets Insert Empty Rows/Columns",
        "",
        "",
    ),
    "389t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Names", "1", "Names="],
            ["2", False, "Variable Names Splitter", "1", ", Variable Name Splitter="],
            ["3", False, "Values", "1", ", Values="],
            ["4", False, "Values Splitter", "1", ", Values Splitter="],
            ["5", True, "Do Maths", "3", ["e", ", Do Maths"]],
            ["6", True, "Max Rounding Digits", "0", ["e", ", Keep Existing"]],
            ["7", True, "Keep Existing", "3", ["e", ", Structure Output (JSON, etc)"]],
            [
                "8",
                True,
                "Structure Output (JSON, etc)",
                "3",
                "Structure Output (JSON, etc)",
            ],
        ],
        "Multiple Variables Set",
        "120",
        "True",
    ),
    "38t": ActionCode("", [], "End If", "105", "False"),
    "390t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Type", "1", "Type="],
            ["2", False, "Title", "1", ", Title="],
            ["3", False, "Text", "1", ", Text="],
            ["4", False, "Default Input", "1", ", Default Input="],
            ["5", True, "Close After (Seconds)", "0", ", Close After (Seconds)="],
        ],
        "Pick Input Dialog",
        "55",
        "True",
    ),
    "391t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Action", "0", ["Action=", "l", "391"]],
            ["2", False, "Title", "1", ", Title="],
            ["3", False, "Text", "1", ", Text="],
            ["4", True, "Type", "0", [", Type=", "l", "391a"]],
            ["5", False, "Animation Images", "1", ", Animation Images="],
            ["6", False, "Animation Tint", "1", ", Animation Tint="],
            ["7", True, "Frame Duration", "0", ", Frame Duration="],
            ["8", True, "Progress", "0", ", Progress="],
            ["9", True, "Max", "0", ", Max="],
            ["10", True, "Use HTML", "3", "Use HTML"],
        ],
        "Progress Dialog",
        "55",
        "True",
    ),
    "392t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Name", "1", "Name="],
            ["2", True, "Structure Type", "1", ", Structure Type="],
            ["3", True, "Prevent JSON Smart Search", "3", "Prevent JSON Smart Search"],
        ],
        "Set Variable Structure Type",
        "120",
        "True",
    ),
    "393t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Names", "1", "Names="],
            ["2", True, "Merge Type", "0", [", Title=", "l", "393"]],
            ["3", True, "Joiner", "1", ", Joiner="],
            ["4", True, "Format", "1", ", Format="],
            ["5", True, "Output", "1", ", Output="],
            ["6", False, "Join Output", "1", ", Join Output="],
        ],
        "Arrays Merge",
        "120",
        "True",
    ),
    "394t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Input Type", "0", ["Input Type=", "l", "394"]],
            ["2", True, "Input", "1", ", Input="],
            ["3", True, "Input Format", "1", ", Input Format="],
            ["4", False, "Input Separator", "1", ", Input Separator="],
            ["5", False, "Output Format", "1", ", Output Format="],
            ["6", False, "Output Format Separator", "1", "Output Format Separator"],
            ["7", False, "Formatted Variable Names", "1", ", Formatted Value Names="],
            ["8", True, "Get All Details", "3", ["e", ", Get All Details"]],
            ["9", True, "Do Maths", "3", ["e", ", Do Maths"]],
            [
                "10",
                True,
                "Output Offset Type",
                "0",
                [", Output Offset Type=", "l", "394a"],
            ],
            ["11", True, "Output Offset", "1", ", Output Offset="],
            ["12", False, "Time Zone", "1", ", Time Zone="],
        ],
        "Parse/Format DateTime",
        "120",
        "True",
    ),
    "395t": ActionCode(
        "",
        [["0", True, "Set", "3", "Set"]],
        "JD Status",
        "130",
        "False",
    ),
    "396t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Type", "0", ["Type=", "l", "396"]],
            ["2", True, "Text", "1", ", Text="],
            ["3", True, "Regex", "1", ", Match Pattern/Regex="],
            ["4", True, "Match Pattern", "1", "Match Pattern"],
        ],
        "Simple Match/Regex",
        "120",
        "True",
    ),
    "397t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Output Hashtags", "3", ["e", "Output Hashtags"]],
        ],
        "Get Material You Colors",
        "104",
        "True",
    ),
    "398t": ActionCode(
        "",
        [["0", True, "SSID", "1", "SSID="]],
        "Connect To WiFi",
        "80",
        "True",
    ),
    "399t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Input", "1", "Input="],
            ["2", True, "Input Minimum", "1", ", Input Minimum="],
            ["3", True, "Input Maximum", "1", ", Input Maximum="],
            ["4", True, "Output Minimum", "1", ", Output Minimum="],
            ["5", True, "Output Maximum", "1", ", Output Maximum="],
            ["6", True, "Invert", "3", "Invert"],
            ["7", True, "Restrict Range", "3", ["e", ", Invert"]],
            ["8", True, "Max Rounding Digits", "0", ["e", ", Restrict Range"]],
            ["9", False, "Output Variable Name", "1", ", Max Rounding Digits="],
        ],
        "Variable Map",
        "120",
        "True",
    ),
    "39t": ActionCode(
        "",
        [
            ["0", True, "Variable", "1", "Variable="],
            ["1", True, "Items", "1", ", Items="],
            [
                "2",
                True,
                "Structure Output (JSON, etc)",
                "3",
                ["e", ", Structure Output (JSON, etc)"],
            ],
        ],
        "For",
        "105",
        "False",
    ),
    "3s": ActionCode(
        "",
        [["0", True, "", "1", "Name="], ["1", True, "", "1", ", Address="]],
        "BT Connected",
        "",
        "",
    ),
    "400t": ActionCode(
        "",
        [
            ["0", True, "From", "1", "From="],
            ["1", True, "To", "1", ", To="],
            ["2", True, "Use Root", "3", ["e", ", Use Root"]],
            ["3", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Move",
        "50",
        "True",
    ),
    "402t": ActionCode(
        "",
        [["0", True, "Output Variables", "5", "Output Variables"]],
        "Get Clipboard",
        "104",
        "True",
    ),
    "404t": ActionCode(
        "",
        [
            ["0", True, "From", "1", "From="],
            ["1", True, "To", "1", ", To="],
            ["2", True, "Use Root", "3", ["e", ", Use Root"]],
            ["3", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Copy File",
        "50",
        "True",
    ),
    "405t": ActionCode(
        "",
        [
            ["0", True, "From", "1", "From="],
            ["1", True, "To", "1", ", To="],
            ["2", True, "Use Root", "3", ["e", ", Use Root"]],
            ["3", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Copy Dir",
        "50",
        "True",
    ),
    "406t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Shred Level", "0", ["e", ", Use Root"]],
            ["2", True, "Use Root", "3", "Use Root"],
            ["3", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Delete File",
        "50",
        "True",
    ),
    "407t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Max Number", "1", ",Max Number="],
            ["2", False, "Mime Type", "1", ", Mime Type="],
            ["3", True, "Copy To Cache", "3", ["e", ", Copy To Cache"]],
        ],
        "Pick Photos",
        "55",
        "True",
    ),
    "40830242s": ActionCode(
        "",
        [
            ["0", True, "", "5", "Configuration="],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON (etc)"]],
        ],
        "AutoNotification Intercept",
        "",
        "",
    ),
    "408t": ActionCode(
        "",
        [
            ["0", True, "Directory", "1", "Directory="],
            ["1", True, "Recurse", "3", ["e", ", Recurse"]],
            ["2", True, "Use Root", "3", ["e", ", Use Root"]],
            ["3", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Delete Directory",
        "50",
        "True",
    ),
    "40966172t": ActionCode("1040876951t", [], "AutoCast", "", ""),
    "409t": ActionCode(
        "",
        [
            ["0", True, "Directory", "1", "Directory="],
            ["1", True, "Create All", "3", ["e", ", Create All"]],
            ["2", True, "Use Root", "3", ["e", ", Use Root"]],
            ["3", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "Create Directory",
        "50",
        "True",
    ),
    "40s": ActionCode(
        "",
        [["0", True, "", "0", "Type="], ["1", True, "", "1", ", Number="]],
        "Call",
        "",
        "",
    ),
    "40t": ActionCode("", [], "End For", "105", "False"),
    "410t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Text", "1", ", Text="],
            ["2", True, "Append", "3", ["e", ", Append"]],
            ["3", True, "Add Newline", "3", ["e", ", Add New Line"]],
        ],
        "Write File",
        "50",
        "True",
    ),
    "411e": ActionCode("", [], "Device Boot", "", ""),
    "412t": ActionCode(
        "",
        [
            ["0", True, "Directory", "1", "Directory="],
            ["1", False, "Match", "1", ", Match="],
            ["2", True, "Include Hidden Files", "3", ["e", ", Include Hidden Files"]],
            ["3", True, "Use Root", "3", ["e", ", Use Root"]],
            ["4", True, "Sort Select", "0", [", Sort Selection=", "l", "412"]],
            ["5", True, "Variable Array", "1", ", Variable Array="],
            ["6", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "List Files",
        "50",
        "True",
    ),
    "413e": ActionCode("", [], "Device Shutdown", "", ""),
    "413t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Tile To Add", "1", "Tile To Add="],
            ["2", True, "Title", "1", "Title="],
            ["3", True, "Icon", "1", "Icon="],
        ],
        "Request Add Tile",
        "55",
        "True",
    ),
    "414549629t": ActionCode("1040876951t", [], "AutoSpotify Search", "", ""),
    "414t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Image", "1", "Image="],
            ["2", True, "Pixel Coordinates", "1", ", Pixel Coordinates="],
        ],
        "Get Pixel Colors",
        "52",
        "True",
    ),
    "415t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File"],
            ["1", False, "Line", "1", "Line"],
            ["2", True, "To Var", "1", "To Var"],
            [
                "3",
                True,
                "Structure Output (JSON, etc)",
                "3",
                "Structure Output (JSON, etc)",
            ],
        ],
        "Read Line",
        "50",
        "True",
    ),
    "41628340e": ActionCode(
        "",
        [["3", True, "", "5", ["", "e", ", Structure Output (JSON, etc)"]]],
        "AutoVoice Intercept",
        "",
        "",
    ),
    "416t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", False, "Para", "1", ", Para="],
            ["2", True, "To Var", "1", ", To Var="],
        ],
        "Read Paragraph",
        "50",
        "True",
    ),
    "417t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "To Var", "1", ", To Var="],
            [
                "2",
                True,
                "Structure Output (JSON, etc)",
                "3",
                ["e", ", Structure Output (JSON, etc)"],
            ],
        ],
        "Read File",
        "50",
        "True",
    ),
    "418t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", False, "Event ID", "1", ", Calendar"],
            ["2", False, "Number Of Events", "1", ", Start Time"],
            ["3", False, "Calendar", "1", ", End Time"],
            ["4", False, "Start Time", "1", ""],
            ["5", False, "End Time", "1", ""],
            ["6", False, "Title", "1", ""],
            ["7", False, "Description", "1", ""],
        ],
        "Get Calendar Events",
        "142",
        "True",
    ),
    "41t": ActionCode(
        "",
        [
            ["0", True, "Number", "1", "Number="],
            ["1", True, "Message", "1", ", Message="],
            ["2", True, "Store In Messaging App", "3", "Store In Messaging App"],
            ["3", False, "SIM Card", "1", ", SIM Card="],
            ["4", True, "Wait For Result", "3", ["e", ", Wait For Result"]],
        ],
        "Send SMS",
        "90",
        "True",
    ),
    "420t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Delete Orig", "3", ["e", ", Delete Dialog"]],
            ["2", True, "Level", "0", ", Level="],
            ["3", False, "Output File", "1", ", Output File="],
        ],
        "Zip",
        "50",
        "True",
    ),
    "421t": ActionCode(
        "",
        [["0", True, "Output Variables", "5", "Output Variables"]],
        "Get Screen Info (Assistant)",
        "40",
        "True",
    ),
    "422e": ActionCode("", [], "Device Storage Low", "", ""),
    "422t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Delete Zip", "3", ["e", ", Delete Zip"]],
        ],
        "UnZip",
        "50",
        "True",
    ),
    "424867932t": ActionCode("1040876951t", [], "AutoBubbles Manage Bubble", "", ""),
    "424e": ActionCode("", [], "Screebl / TSC", "", ""),
    "424t": ActionCode(
        "",
        [["0", True, "Output Variables", "5", "Output Variables"]],
        "Get Battery Info",
        "104",
        "True",
    ),
    "425e": ActionCode("", [], "K9 Email Received", "", ""),
    "425t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "WiFi",
        "80",
        "True",
    ),
    "426e": ActionCode("", [], "Widget Locker", "", ""),
    "426t": ActionCode(
        "",
        [
            ["0", True, "Action", "0", ["Action=", "l", "426"]],
            ["1", True, "Force", "3", ["e", ", Force"]],
            ["2", True, "Report Failure", "3", ["e", ", Report Failure"]],
        ],
        "WiFi Net",
        "80",
        "False",
    ),
    "427019141t": ActionCode(
        "1040876951t",
        [],
        "AutoNotification Replace Gmail Notifications",
        "",
        "",
    ),
    "427e": ActionCode("", [], "OpenWatch", "", ""),
    "427t": ActionCode(
        "",
        [["0", True, "Policy", "0", ["Policy=", "l", "427"]]],
        "WiFi Sleep",
        "80",
        "False",
    ),
    "428e": ActionCode("", [], "Kaloer Clock", "", ""),
    "429032033t": ActionCode("1040876951t", [], "AutoContacts Details", "", ""),
    "42924197t": ActionCode("1040876951t", [], "Notification Listener", "", ""),
    "429e": ActionCode("", [], "Locale Changed", "", ""),
    "42t": ActionCode(
        "",
        [
            ["0", True, "Number", "1", "Number="],
            ["1", True, "Port", "0", ", Port="],
            ["2", True, "Data", "1", ", Data="],
        ],
        "Send Data SMS",
        "90",
        "True",
    ),
    "430t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ["e", ", Only Monitor"]],
            ["1", True, "Only Monitor", "3", "Only Monitor"],
        ],
        "Restart Tasker",
        "110",
        "False",
    ),
    "431t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Action", "0", ["Action=", "l", "431"]],
            ["2", True, "Services", "1", ", Services"],
            ["3", False, "Services", "1", "Services"],
        ],
        "Accessibility Services",
        "104",
        "True",
    ),
    "432t": ActionCode(
        "",
        [["0", True, "Output Variables", "5", "Output Variables"]],
        "Get Network Info",
        "80",
        "True",
    ),
    "433t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Output Variables", "5", "Output Variables"],
        ],
        "Mobile Data",
        "80",
        "True",
    ),
    "438t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Device IDs/Names", "1", "Device IDs/Name="],
            ["2", False, "Set", "1", ", Set="],
            ["3", False, "Colour", "1", ", Color="],
            ["4", False, "Brightness", "1", ", Brightness="],
        ],
        "Matter Light (Experimental)",
        "141",
        "True",
    ),
    "439t": ActionCode("", [["0", True, "Set", "3", "Set"]], "WiMax", "80", "False"),
    "43t": ActionCode("", [], "Else", "105", "False"),
    "440t": ActionCode(
        "",
        [["0", True, "To", "1", "To"]],
        "Set Timezone",
        "104",
        "False",
    ),
    "441t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Output Variables", "5", "Output Variables"],
        ],
        "Work Profile",
        "104",
        "True",
    ),
    "442t": ActionCode(
        "",
        [["0", True, "Punch", "0", "Punch"], ["1", False, "Note", "1", "Note"]],
        "SleepBot",
        "130",
        "False",
    ),
    "443t": ActionCode(
        "",
        [
            ["0", True, "Cmd", "0", ["Cmd=", "l", "443"]],
            ["1", True, "Simulate Media Button", "3", ["e", ", Simulate Media Button"]],
            ["2", True, "Package/App Name", "2", ", Package/App Name="],
            [
                "3",
                True,
                "Use Notification If Available",
                "3",
                ["e", ", Use Notification If Available"],
            ],
        ],
        "Media Control",
        "65",
        "False",
    ),
    "444e": ActionCode("", [], "Pomodroido", "", ""),
    "444t": ActionCode(
        "",
        [
            ["0", True, "Set", "0", "Set"],
            ["1", True, "Strobe (Hertz)", "0", "Strobe (Hertz)"],
        ],
        "TeslaLED",
        "130",
        "False",
    ),
    "445e": ActionCode("", [], "Radardroid", "", ""),
    "445t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Start", "0", ", Start="],
            ["2", True, "Loop", "3", ["e", ", Loop"]],
            ["3", True, "Stream", "0", ["Cmd=", "l", "171"]],
            [
                "4",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
        ],
        "Music Play",
        "65",
        "True",
    ),
    "446e": ActionCode("", [], "Gentle Alarm", "", ""),
    "446t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", False, "Path", "1", "Path="],
            ["2", True, "Type", "1", ", Type="],
            ["3", False, "Name/Path Filter", "1", ", Name/Path Filter="],
            ["4", False, "Other Filters", "1", ", Other Filters="],
            ["5", True, "Recurse", "3", ["e", ", Recurse"]],
            ["6", False, "Sort", "1", "Sort"],
        ],
        "Get Files/Folders Properties",
        "50",
        "True",
    ),
    "447e": ActionCode("", [], "Reddit Notify", "", ""),
    "447t": ActionCode(
        "",
        [
            ["0", True, "Directory", "1", "Directory="],
            ["1", True, "Subdirs", "3", ["e", ", Subdirs"]],
            ["2", True, "Audio Only", "3", ["e", ", Audio Only"]],
            ["3", True, "Random", "3", ["e", ", Random"]],
            ["4", True, "Flash", "3", ["e", ", Flash"]],
            ["5", True, "Maximum Tracks", "0", ", Maximum Tracks="],
        ],
        "Music Play Dir",
        "65",
        "True",
    ),
    "448e": ActionCode("", [], "Notify My Android", "", ""),
    "448t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Names", "1", "Names="],
        ],
        "Array Compare",
        "120",
        "False",
    ),
    "449t": ActionCode(
        "",
        [["0", True, "Clear Dir", "3", ["e", ", Clear Dir"]]],
        "Music Stop",
        "65",
        "True",
    ),
    "450e": ActionCode(
        "",
        [["0", True, "", "1", ",Name="], ["1", True, "", "1", ", Package="]],
        "New Package",
        "",
        "",
    ),
    "450t": ActionCode(
        "",
        [
            ["0", True, "Enable", "3", "Enable"],
            ["1", True, "Keep MMS", "3", "Keep MMS"],
            ["2", True, "Notify", "3", "Notify"],
        ],
        "APN Droid",
        "130",
        "False",
    ),
    "451e": ActionCode(
        "",
        [["0", True, "", "1", "Package="]],
        "Package Removed",
        "",
        "",
    ),
    "451t": ActionCode(
        "",
        [["0", True, "Jump", "0", "Jump="]],
        "Music Skip",
        "65",
        "True",
    ),
    "452t": ActionCode("", [], "Show Running Tasks", "110", "False"),
    "453e": ActionCode(
        "",
        [["0", True, "", "1", "Name="], ["1", True, "", "1", ", Package="]],
        "Package Updated",
        "",
        "",
    ),
    "453t": ActionCode(
        "",
        [["0", True, "Jump", "0", "Jump="]],
        "Music Back",
        "65",
        "True",
    ),
    "454t": ActionCode("", [], "Show Active Profiles", "110", "False"),
    "455t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Source", "0", [", Source=", "l", "455"]],
            ["2", True, "MaxSize", "0", ", MaxSize="],
            ["3", True, "Codec", "0", [", Format=", "l", "455a"]],
            ["4", True, "Format", "0", "Format"],
        ],
        "Record Audio",
        "65",
        "True",
    ),
    "456t": ActionCode("", [["0", True, "Set", "0", "Set"]], "JD APN", "130", "False"),
    "457t": ActionCode(
        "",
        [["0", True, "Type", "0", "Type"], ["1", True, "Sound", "1", "Sound"]],
        "Default Ringtone",
        "20",
        "False",
    ),
    "458t": ActionCode(
        "",
        [["0", True, "Cmd", "0", "Cmd"]],
        "WidgetLocker",
        "130",
        "False",
    ),
    "459t": ActionCode(
        "",
        [["0", False, "File", "1", "File="]],
        "Scan Media",
        "65",
        "False",
    ),
    "460e": ActionCode("", [], "Wallpaper Changed", "", ""),
    "460t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Grayscale", "3", ["e", ", 'Grayscale' On"]],
            ["2", True, "Dim Wallpaper", "3", ["e", ", 'Wallpaper' On"]],
            [
                "3",
                True,
                "Disable Always On Display",
                "3",
                ["e", ", 'Disable Always On Display' On"],
            ],
        ],
        "Set Device Effects",
        "104",
        "True",
    ),
    "461e": ActionCode(
        "",
        [
            ["0", True, "", "2", "Owner Application="],
            ["1", True, "", "1", ", Title="],
            ["2", True, "", "1", ", Text="],
            ["3", True, "", "1", ", Subtext="],
            ["4", True, "", "1", ", Messages="],
            ["5", True, "", "1", ", Other Text="],
            ["6", True, "", "1", ", Cat="],
            ["7", True, "", "0", ["", "e", ", New Only"]],
        ],
        "Notification",
        "",
        "",
    ),
    "461t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Widget Name", "1", "Widget Name="],
            ["2", True, "Layout", "1", ", Layout="],
            ["3", False, "Background Colour", "1", ", Background Color="],
            ["4", False, "Title", "1", ", Title="],
            ["5", False, "Texts", "1", ", Texts="],
            ["6", False, "Text Styles", "1", ", Text Styles="],
            ["7", False, "Images", "1", ", Images="],
            ["8", False, "Image Tints", "1", ", Image Tint="],
            ["9", False, "Image Sizes", "1", ", Image Sizes="],
            ["10", False, "Tasks", "1", ", Tasks="],
            ["11", False, "Commands", "1", ", Commands="],
            ["12", False, "Command Prefix", "1", ", Command Prefix="],
            ["13", False, "Custom Layout", "1", ", Command Layout="],
            ["14", True, "Material You Colors", "3", ["e", ", Material You Colors"]],
            ["15", True, "Number of Columns", "1", ", Number of Columns="],
            ["16", True, "Ask To Add If Not Present", "3", "Ask To Add If Not Present"],
        ],
        "Widget v2",
        "110",
        "True",
    ),
    "462e": ActionCode("", [], "Button Widget Clicked", "", ""),
    "462t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", "Output Variables"],
            ["1", True, "Mode", "0", ["Mode=", "l", "462"]],
        ],
        "Remote Action Execution",
        "110",
        "True",
    ),
    "463e": ActionCode("", [], "New Window", "", ""),
    "463t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            [
                "1",
                True,
                "Continue Task Immediately",
                "3",
                ", Continue Task Immediately",
            ],
            ["2", True, "Action", "1", ", Action"],
            ["3", True, "Event ID", "1", ", Event ID"],
            ["4", False, "Title", "1", ", Title"],
            ["5", False, "Description", "1", ", Description"],
            ["6", False, "Start Time", "1", ", Start Time"],
            ["7", False, "End Time", "1", ", End Time"],
        ],
        "Edit Calendar Via App",
        "142",
        "True",
    ),
    "464e": ActionCode(
        "",
        [
            ["0", True, "", "2", "Owner Application="],
            ["1", True, "", "1", ", Title="],
            ["2", True, "", "1", ", Text="],
            ["3", True, "", "1", ", Subtext="],
            ["4", True, "", "1", ", Messages="],
            ["5", True, "", "1", ", Other Text="],
        ],
        "Notification Removal",
        "",
        "",
    ),
    "464t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", True, "Action", "1", ", Calendar"],
            ["2", True, "Calendar", "1", ", Action"],
            ["3", True, "Event ID", "1", ", Event ID"],
            ["4", False, "Title", "1", ", Title"],
            ["5", False, "Description", "1", ", Description"],
            ["6", False, "All Day", "1", ", All Day"],
            ["7", False, "Start Time", "1", ", Start Time"],
            ["8", False, "End Time", "1", ", End Time"],
            ["9", False, "Organizer", "1", ", Organizer"],
            ["10", False, "Location", "1", ", Location"],
            ["11", False, "Availability", "1", ", Availability"],
            ["12", False, "Colour", "1", ""],
        ],
        "Edit Calendar Event",
        "142",
        "True",
    ),
    "465t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", True, "Action", "1", ", Action"],
            ["2", True, "Event ID", "1", ", Event ID"],
            ["3", True, "Reminder ID", "1", ", Reminder ID"],
            ["4", True, "Minutes Prior", "1", ", Minutes Prior"],
            ["5", True, "Method", "1", ", Method"],
        ],
        "Edit Calendar Reminder",
        "142",
        "True",
    ),
    "466t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", False, "Reminder ID", "1", ", Calendar"],
            ["2", False, "Event ID", "1", ", Event ID"],
            ["3", False, "Calendar", "1", ", Reminder ID"],
        ],
        "Get Calendar Reminders",
        "142",
        "True",
    ),
    "467t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", True, "Action", "1", ", Action"],
            ["2", True, "Event ID", "1", ", Event ID"],
            ["3", True, "Attendee ID", "1", ", Attendee ID"],
            ["4", False, "Name", "1", ", Name"],
            ["5", False, "Email", "1", ", Email"],
            ["6", False, "Status", "1", ", Status"],
            ["7", False, "Relationship", "1", ", Relationship"],
            ["8", False, "Type", "1", ", Type"],
        ],
        "Edit Calendar Attendee",
        "142",
        "True",
    ),
    "468t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", False, "Attendee ID", "1", ", Calendar"],
            ["2", False, "Event ID", "1", ", Event ID"],
            ["3", False, "Calendar", "1", ", Attendee ID"],
        ],
        "Get Calendar Attendees",
        "142",
        "True",
    ),
    "469t": ActionCode(
        "",
        [["0", True, "Keyboard", "1", ", Keyboard"]],
        "Set Keyboard",
        "104",
        "True",
    ),
    "46t": ActionCode(
        "",
        [["0", True, "Name", "1", "Name="]],
        "Create Scene",
        "102",
        "True",
    ),
    "470t": ActionCode(
        "",
        [["0", True, "Output Variables", "5", ", Output Variables"]],
        "Get Keyboard Info",
        "104",
        "True",
    ),
    "473t": ActionCode(
        "",
        [
            ["0", True, "Output Variables", "5", ", Output Variables"],
            ["1", False, "Latitude", "1", ", Latitude"],
            ["2", False, "Longitude", "1", ", Longitude"],
        ],
        "Get Sunrise/Sunset Times",
        "60",
        "True",
    ),
    "475t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Delete Orig", "3", ["e", ", Delete Orig"]],
        ],
        "GZip",
        "50",
        "True",
    ),
    "476t": ActionCode(
        "",
        [
            ["0", True, "File", "1", "File="],
            ["1", True, "Delete Zip", "3", ["e", ", Delete Zip"]],
        ],
        "GUnzip",
        "50",
        "True",
    ),
    "47t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Display As", "0", [", Display As=", "l", "47"]],
            ["2", True, "Horizontal Position", "0", "Horizontal Position"],
            ["3", True, "Vertical Position", "0", "Vertical Position"],
            ["4", True, "Animation", "0", "Animation"],
            ["5", True, "Show Exit Button", "3", "Show Exit Button"],
            ["6", True, "Show Over Keyguard", "3", ["e", ", Show Exit Button"]],
            [
                "7",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
            [
                "8",
                True,
                "Allow Outside Boundaries",
                "3",
                ["e", ", Allow Outside Boundaries"],
            ],
            ["9", True, "Blocking Overlay +", "3", ["e", ", Blocking Overlay +"]],
            ["10", True, "Overlay +", "3", "Overlay +"],
        ],
        "Show Scene",
        "102",
        "True",
    ),
    "48t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Animation", "0", ["Animation=", "l", "48"]],
        ],
        "Hide Scene",
        "102",
        "True",
    ),
    "490t": ActionCode(
        "",
        [
            ["0", True, "Action", "0", ["File=", "l", "490"]],
            ["1", True, "Use New API", "3", ["e", ", Use New API"]],
        ],
        "Media Button Events",
        "65",
        "False",
    ),
    "49t": ActionCode(
        "",
        [["0", True, "Name", "1", "Name="]],
        "Destroy Scene",
        "102",
        "True",
    ),
    "4e": ActionCode("", [], "Phone Idle", "", ""),
    "4s": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name", "", ""],
            ["1", True, "", "1", "Address", "", ""],
            ["2", True, "", "0", ["Major Device Class=", "l", "4"]],
            ["3", True, "", "0", ["e", ", Standard Devices"]],
            ["4", True, "", "0", ["e", ", Low Energy (LE) Devices"]],
            ["5", True, "", "0", ["e", ", Unpaired Devices"]],
            ["6", True, "", "0", ["e", ", Toggle Bluetooth"]],
        ],
        "BT Near",
        "",
        "",
    ),
    "502102143t": ActionCode("1040876951t", [], "AutoSheets Get Spreadsheet", "", ""),
    "502807688t": ActionCode("1040876951t", [], "AutoAppsHub SendCommand", "", ""),
    "50s": ActionCode("", [], "Keyboard Out", "", ""),
    "50t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element Match", "1", ", Element="],
            ["2", True, "Value", "0", ", Value="],
        ],
        "Element Value",
        "102",
        "True",
    ),
    "511t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", [", File=", "l", "switch_set"]],
            ["1", False, "Level", "1", "Level"],
        ],
        "Torch",
        "10",
        "False",
    ),
    "512t": ActionCode(
        "",
        [["0", True, "Set", "0", [", File=", "l", "512"]]],
        "Status Bar",
        "40",
        "True",
    ),
    "513t": ActionCode("", [], "Close System Dialogs", "55", "True"),
    "51t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Position", "0", [", Position=", "l", "51"]],
            ["3", False, "Text", "1", ", Text="],
            ["4", False, "Selection", "1", ", Selection="],
        ],
        "Element Text",
        "102",
        "True",
    ),
    "523t": ActionCode(
        "",
        [
            ["0", True, "Title", "1", "Title="],
            ["1", False, "Text", "1", ", Text="],
            ["2", True, "Icon", "4", ", Icon="],
            ["3", True, "Number", "0", "Number"],
            ["4", True, "Permanent", "3", ["e", ", Permanent"]],
            ["5", True, "Priority", "0", ", Priority="],
            ["6", True, "Repeat Alert", "3", ["e", ", Repeat Alert"]],
            ["7", True, "LED Colour", "0", [", LED Color=", "l", "523"]],
            ["8", True, "LED Rate", "0", ", LED Rate="],
            ["9", False, "Sound File", "1", ", Sound File="],
            ["10", False, "Vibration Pattern", "1", ", Vibration Pattern="],
            ["11", False, "Category", "1", ", Category="],
            ["12", False, "Intensity Pattern", "1", ", Intensity Pattern="],
        ],
        "Notify",
        "10",
        "False",
    ),
    "525t": ActionCode(
        "",
        [
            ["0", True, "Title", "1", ":Title="],
            ["1", False, "Text", "1", ", Text="],
            ["2", True, "Icon", "4", ", Icon="],
            ["3", True, "Number", "0", ""],
            ["4", True, "Colour", "0", [", LED Color=", "l", "523"]],
            ["5", True, "Rate", "0", ", Rate="],
            ["6", True, "Priority", "0", ", Priority="],
            ["7", True, "Repeat Alert", "3", ["e", ", Repeat Alert"]],
        ],
        "Notify LED",
        "10",
        "False",
    ),
    "536t": ActionCode(
        "",
        [
            ["0", True, "Title", "1", "Title="],
            ["1", False, "Text", "1", ", Text="],
            ["2", True, "Icon", "4", ", Icon="],
            ["3", True, "Number", "0", "Number"],
            ["4", False, "Pattern", "1", ", Pattern="],
            ["5", True, "Priority", "0", ", Priority="],
            ["6", True, "Repeat Alert", "3", ["e", ", Repeat Alert"]],
        ],
        "Notify Vibrate",
        "10",
        "False",
    ),
    "538t": ActionCode(
        "",
        [
            ["0", True, "Title", "1", "Title="],
            ["1", False, "Text", "1", ", Text="],
            ["2", True, "Icon", "4", ", Icon="],
            ["3", True, "Number", "0", "Number"],
            ["4", False, "Sound File", "1", ", Sound File="],
            ["5", True, "Priority", "0", ", Priority="],
            ["6", True, "Repeat Alert", "3", "Repeat Alert"],
        ],
        "Notify Sound",
        "10",
        "False",
    ),
    "53t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Mode", "0", [", Mode=", "l", "53"]],
            ["3", True, "Value", "1", "Value"],
        ],
        "Element Web Control",
        "102",
        "True",
    ),
    "543t": ActionCode(
        "",
        [
            ["0", True, "Seconds", "0", "Seconds="],
            ["1", False, "Message", "1", ", Message="],
            ["2", True, "Show UI", "3", ["e", ", Show UI"]],
        ],
        "Start System Timer",
        "104",
        "False",
    ),
    "544t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Type", "0", [", Type=", "l", "544"]],
        ],
        "Timer Widget Control",
        "110",
        "False",
    ),
    "545t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Min", "0", ", Min="],
            ["2", True, "Max", "0", ", Max="],
        ],
        "Variable Randomize",
        "120",
        "False",
    ),
    "546t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Seconds", "0", ", Seconds="],
            ["2", True, "Minutes", "0", ", Minutes="],
            ["3", True, "Hours", "0", ", Hours="],
            ["4", True, "Days", "0", ", Days="],
        ],
        "Timer Widget Set",
        "110",
        "False",
    ),
    "547t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "To", "1", ", To="],
            ["2", True, "Recurse Variables", "3", ["e", ", Recursive Variables"]],
            ["3", True, "Do Maths", "3", ["e", ", Do Maths"]],
            ["4", True, "Append", "3", ["e", ", Append"]],
            ["5", True, "Max Rounding Digits", "0", ", Max Rounding Digits="],
            [
                "6",
                True,
                "Structure Output (JSON, etc)",
                "3",
                ["e", ", Structure Output (JSON, etc)"],
            ],
        ],
        "Variable Set",
        "120",
        "True",
    ),
    "548t": ActionCode(
        "",
        [
            ["0", True, "Text", "1", "Text="],
            ["1", True, "Long", "3", ["e", ", Long"]],
            ["2", True, "Tasker Layout", "3", ["e", ", Tasker Layout"]],
            ["3", False, "Title", "1", ", Title="],
            ["4", False, "Icon", "1", ", Icon="],
            ["5", False, "Icon Size", "1", " Icon Size="],
            ["6", False, "Background Colour", "1", ", Background Color="],
            ["7", False, "Task", "1", ", Task="],
            ["8", False, "Timeout", "1", ", Timeout="],
            [
                "9",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
            ["10", False, "Text Colour", "1", ", Text Color="],
            ["11", True, "Dismiss On Click", "3", ["e", ", Dismiss On Click"]],
            ["12", True, "Show Over Everything", "3", ["e", ", Show Over Everything"]],
            ["13", False, "Position", "1", ", Position="],
            ["14", True, "Use HTML", "3", ["e", ", Use HTML"]],
            ["15", False, "ID", "1", "ID"],
        ],
        "Flash",
        "10",
        "True",
    ),
    "549t": ActionCode(
        "",
        [
            ["0", False, "Name", "1", "Name="],
            ["1", True, "Pattern Matching", "3", ["e", ", Pattern Matching"]],
            ["2", True, "Local Variables Only", "3", ["e", ", Clear All Variables"]],
            ["3", True, "Clear All Variables", "3", "Clear All Variables"],
        ],
        "Variable Clear",
        "120",
        "False",
    ),
    "54t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Colour", "1", " Colour="],
        ],
        "Element Text Colour",
        "102",
        "True",
    ),
    "550t": ActionCode(
        "",
        [
            ["0", False, "Title", "1", "Title="],
            ["1", True, "Text", "1", ", Text="],
            ["2", False, "Background Image", "1", ", Background Image="],
            ["3", True, "Layout", "1", "Layout"],
            ["4", True, "Timeout (Seconds)", "0", ", Layout="],
            ["5", True, "Show Over Keyguard", "3", ", Timeout (Seconds)="],
        ],
        "Popup",
        "10",
        "False",
    ),
    "551t": ActionCode(
        "",
        [
            ["0", False, "Title", "1", "Title"],
            ["1", False, "Background Image", "1", "Background Image"],
            ["2", True, "Layout", "1", "Layout"],
            ["3", True, "Timeout (Seconds)", "0", "Timeout (Seconds)"],
            ["4", True, "Show Over Keyguard", "3", "Show Over Keyguard"],
        ],
        "Menu",
        "10",
        "False",
    ),
    "552t": ActionCode(
        "",
        [
            ["0", False, "Text", "1", "Text="],
            ["1", True, "Mode", "0", [", Mode=", "l", "552"]],
            ["2", False, "Task", "1", ", Task="],
            ["3", False, "Task", "1", ", Task="],
            ["4", False, "Task", "1", ", Task="],
            ["5", False, "Background Image", "1", ", Background Image="],
            ["6", True, "Layout", "1", ", Layout="],
            ["7", True, "Timeout (Seconds)", "0", ", Timeout (Seconds)="],
            ["8", True, "Show Over Keyguard", "3", ["e", ", Show Over Keyguard"]],
        ],
        "Popup Task Buttons",
        "10",
        "False",
    ),
    "553t": ActionCode("", [], "SMS Backup+", "130", "False"),
    "555t": ActionCode(
        "",
        [["0", True, "Cmd", "0", "Cmd"]],
        "BeyondPod",
        "130",
        "False",
    ),
    "556t": ActionCode(
        "",
        [["0", True, "Cmd", "0", "Cmd"]],
        "GrazeRSS",
        "130",
        "False",
    ),
    "557649458t": ActionCode("1040876951t", [], "AutoWear Time", "", ""),
    "558t": ActionCode(
        "",
        [["0", True, "Title", "1", "Title"], ["1", True, "Message", "1", "Message"]],
        "Android Notifier",
        "130",
        "False",
    ),
    "559t": ActionCode(
        "",
        [
            ["0", True, "Text", "1", "Text="],
            ["1", True, "Engine:Voice", "1", ", Engine Voice="],
            ["2", True, "Stream", "0", [", Stream=", "l", "171"]],
            ["3", True, "Pitch", "0", ", Pitch="],
            ["4", True, "Speed", "0", ", Speed="],
            ["5", True, "Respect Audio Focus", "3", ["e", ", Respect Audio Focus"]],
            ["6", True, "Network", "3", ["e", ", Network"]],
            [
                "7",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
        ],
        "Say",
        "10",
        "True",
    ),
    "55t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Colour", "1", " Colour="],
            ["3", True, "End Colour", "1", " End Colour="],
        ],
        "Element Back Colour",
        "102",
        "True",
    ),
    "563213414t": ActionCode("1040876951t", [], "AutoNotification Table", "", ""),
    "565385068t": ActionCode("1040876951t", [], "AutoNotification Query", "", ""),
    "566t": ActionCode(
        "",
        [
            ["0", True, "Hours", "0", "Hours="],
            ["1", True, "Minutes", "0", ", Minutes="],
            ["2", False, "Label", "1", ", Label="],
            ["3", False, "Sound", "1", ", Sound="],
            ["4", True, "Vibrate", "0", [", Vibrate=", "l", "566"]],
            ["5", True, "Confirm", "3", ["e", ", Confirm"]],
        ],
        "Set Alarm",
        "104",
        "False",
    ),
    "567t": ActionCode(
        "",
        [
            ["0", False, "In / For (Minutes)", "1", "In/For Minutes="],
            ["1", True, "Calendar", "1", ", Calendar="],
            ["2", True, "Title", "1", ", Title="],
            ["3", False, "Description", "1", ", Description="],
            ["4", False, "Location", "1", ", Location="],
            ["5", True, "Available", "3", ["e", ", Available"]],
            ["6", True, "All Day", "3", ["e", ", All Day"]],
        ],
        "Calendar Insert",
        "142",
        "True",
    ),
    "5683503e": ActionCode(
        "",
        [
            ["0", True, "", "5", ""],
            ["3", True, "", "1", ["", "e", ", Structure Output (JSON, etc)"]],
        ],
        "AutoInput UI Action",
        "",
        "",
    ),
    "568t": ActionCode(
        "",
        [["0", True, "Cmd", "0", "Cmd"]],
        "DailyRoads Voyager",
        "130",
        "False",
    ),
    "56t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Width", "0", ", Width="],
            ["3", True, "Colour", "1", ", Colour="],
        ],
        "Element Border",
        "102",
        "True",
    ),
    "570237327t": ActionCode("1040876951t", [], "AutoSheets Format Cells", "", ""),
    "57t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Orientation", "0", [", Orientation=", "l", "57"]],
            ["3", True, "X", "0", ", X="],
            ["4", True, "Y", "0", ", Y="],
            ["5", True, "Animation Time (MS)", "0", ", Animation Time (MS)="],
        ],
        "Element Position",
        "102",
        "True",
    ),
    "580953799e": ActionCode(
        "",
        [["3", True, "", "5", ["", "e", ", Structure Output (JSON, etc)"]]],
        "AutoShare",
        "",
        "",
    ),
    "58t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Orientation", "0", [", Orientation=", "l", "57"]],
            ["3", True, "Width", "0", ", Width="],
            ["4", True, "Height", "0", ", Height="],
            ["5", True, "Animation Time (MS)", "0", ", Animation Time (MS)="],
        ],
        "Element Size",
        "102",
        "True",
    ),
    "590t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", False, "Splitter", "1", ", Splitter="],
            ["2", True, "Delete Base", "3", ["e", ", Delete Base"]],
            ["3", True, "Regex", "3", ["e", ", Regex"]],
        ],
        "Variable Split",
        "120",
        "True",
    ),
    "592t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", False, "Joiner", "1", ", Joiner="],
            ["2", True, "Delete Parts", "3", ["e", ", Delete Parts"]],
        ],
        "Variable Join",
        "120",
        "False",
    ),
    "595t": ActionCode(
        "",
        [
            ["0", False, "Title", "1", "Title="],
            ["1", True, "Variable", "1", ", Variable="],
            ["2", True, "Input Type", "0", [", Input Type=", "l", "595"]],
            ["3", False, "Default", "1", ", Default="],
            ["4", False, "Background Image", "1", ", Background Image="],
            ["5", True, "Layout", "1", ", Layout="],
            ["6", True, "Timeout (Seconds)", "0", ", Timeout (Seconds)="],
            ["7", True, "Show Over Keyguard", "3", ["e", ", Show Over Keyguard"]],
        ],
        "Variable Query",
        "120",
        "False",
    ),
    "596t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Function", "0", [", Function=", "l", "596"]],
            ["2", False, "Store Result In", "1", ", Store Result In="],
            ["3", True, "Mode", "0", "Mode"],
        ],
        "Variable Convert",
        "120",
        "True",
    ),
    "597t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "From", "0", ", From="],
            ["2", True, "Length", "0", ", Length="],
            ["3", True, "Adapt To Fit", "3", ["e", ", Adopt To Fit"]],
            ["4", False, "Store Result In", "1", ", Store Result In="],
        ],
        "Variable Section",
        "120",
        "False",
    ),
    "598t": ActionCode(
        "",
        [
            ["0", True, "Variable", "1", "Variable="],
            ["1", True, "Search", "1", ", Search="],
            ["2", True, "Ignore Case", "3", ["e", ", Ignore Case"]],
            ["3", True, "Multi-Line", "3", ["e", ", Multi-Line"]],
            ["4", True, "One Match Only", "3", ["e", ", One Match Only"]],
            ["5", False, "Store Matches In Array", "1", ", Show Matches In Array="],
            ["6", True, "Replace Matches", "3", ["e", ", Replace Matches"]],
            ["7", False, "Replace With", "1", "Replace With"],
        ],
        "Variable Search Replace",
        "120",
        "True",
    ),
    "599e": ActionCode(
        "",
        [
            ["0", True, "", "1", "Action="],
            ["1", True, "", "0", [", Cat=", "l", "877"]],
            ["2", True, "", "0", [", Cat=", "l", "877"]],
            ["3", False, "", "1", ", Schema="],
            ["4", False, "", "1", ", Mime Type="],
            ["5", True, "", "0", ", Priority="],
            ["6", True, "", "1", ["", "e", ", Stop Event"]],
        ],
        "Intent Received",
        "",
        "",
    ),
    "599t": ActionCode(
        "",
        [["0", True, "Cmd", "0", "Cmd"]],
        "Due Today",
        "130",
        "False",
    ),
    "59t": ActionCode("", [["0", True, "Type", "0", "Type"]], "Reboot", "104", "True"),
    "5s": ActionCode("", [], "Calendar Entry", "", ""),
    "60t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Lat,Long", "1", ", Lat,Long="],
            ["3", False, "Label", "1", ", Label="],
            ["4", False, "Text Colour", "1", ", Spot Radius (Meters)="],
            ["5", True, "Text Size", "0", ", Spot Color="],
            ["6", True, "Spot Radius (Metres)", "0", "Spot Radius (Metres)"],
            ["7", False, "Spot Colour", "1", "Spot Colour"],
            ["8", True, "Icon", "4", "Icon"],
        ],
        "Element Add GeoMarker",
        "102",
        "True",
    ),
    "610246503t": ActionCode("1040876951t", [], "AutoCast Query", "", ""),
    "611944049t": ActionCode("1040876951t", [], "AutoCast Speak", "", ""),
    "612t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Mode", "0", [", Mode=", "l", "612"]],
            ["3", True, "Value", "1", ", MilliSeconds="],
        ],
        "Element Video Control",
        "102",
        "True",
    ),
    "61t": ActionCode("", [["0", True, "Time", "0", "Time="]], "Vibrate", "10", "True"),
    "62t": ActionCode(
        "",
        [
            ["0", True, "Pattern", "1", "Pattern="],
            ["1", False, "Intensity Pattern", "1", "Intensity Pattern"],
        ],
        "Vibrate Pattern",
        "10",
        "True",
    ),
    "63t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", False, "Lat,Long", "1", " Lat,Long="],
            ["3", False, "Label", "1", " Label="],
        ],
        "Element Delete GeoMarker",
        "102",
        "True",
    ),
    "643t": ActionCode(
        "",
        [["0", True, "Cmd", "0", "Cmd"], ["1", True, "Status", "0", "Status"]],
        "OfficeTalk",
        "130",
        "False",
    ),
    "64t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Mode", "0", [", Mode=", "l", "64"]],
            ["3", True, "Value", "1", "Value"],
        ],
        "Element Map Control",
        "102",
        "True",
    ),
    "657t": ActionCode("", [], "Record Audio Stop", "65", "True"),
    "658527372t": ActionCode("1040876951t", [], "AutoTools HTML Read", "", ""),
    "65t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element Match", "1", ", Element Match="],
            ["2", True, "Set", "3", [", Set=", "l", "65"]],
            ["3", True, "Animation Time (MS)", "0", "Animation Time (MS)="],
            [
                "4",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
        ],
        "Element Visibility",
        "102",
        "True",
    ),
    "664t": ActionCode(
        "",
        [
            ["0", False, "Return", "1", "Class or Object="],
            ["1", False, "Class Or Object", "1", ", Function="],
            ["2", True, "Function", "1", "Function"],
            ["3", False, "Param", "1", "Param"],
            ["4", False, "Param", "1", "Param"],
            ["5", False, "Param", "1", "Param"],
            ["6", False, "Param", "1", "Param"],
            ["7", False, "Param", "1", "Param"],
            ["8", False, "Param", "1", "Param"],
            ["9", False, "Param", "1", "Param"],
        ],
        "Java Function",
        "35",
        "True",
    ),
    "665t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", ["Mode=", "l", "665"]],
            ["1", False, "Name", "1", ", Name="],
        ],
        "Java Object",
        "35",
        "False",
    ),
    "667t": ActionCode(
        "",
        [
            ["0", True, "Mode", "0", "Mode"],
            ["1", True, "File", "1", "File"],
            ["2", True, "Table", "1", "Table"],
            ["3", False, "Columns", "1", "Columns"],
            ["4", False, "Query", "1", "Query"],
            ["5", False, "Selection Parameters", "1", "Selection Parameters"],
            ["6", False, "Order By", "1", "Order By"],
            ["7", False, "Output Column Divider", "1", "Output Column Divider"],
            ["8", True, "Variable Array", "1", "Variable Array"],
            ["9", True, "Use Root", "3", "Use Root"],
            ["10", True, "Use Global Namespace", "3", "Use Global Namespace"],
        ],
        "SQL Query",
        "50",
        "True",
    ),
    "66t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Image", "4", ", Image="],
        ],
        "Element Image",
        "102",
        "True",
    ),
    "67t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Set Depth", "0", ", Set Depth="],
        ],
        "Element Depth",
        "102",
        "True",
    ),
    "68t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Set", "3", ["e", ", Set"]],
        ],
        "Element Focus",
        "102",
        "True",
    ),
    "697t": ActionCode("", [], "Shut Up", "10", "False"),
    "699t": ActionCode(
        "",
        [
            ["0", True, "Text", "1", "Text="],
            ["1", True, "Engine:Voice", "1", ", Engine/Voice="],
            ["2", True, "File", "1", ", File="],
            ["3", True, "Pitch", "0", ", Pitch="],
            ["4", True, "Speed", "0", ", Speed="],
            ["5", True, "Network", "3", ["e", ", Network"]],
            [
                "6",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
        ],
        "Say To File",
        "10",
        "True",
    ),
    "69t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Type", "0", [", Set=", "l", "69"]],
            ["2", True, "Visible", "3", ["e", ", Visible"]],
            ["3", True, "Content", "1", ", Content="],
        ],
        "Element Create",
        "102",
        "True",
    ),
    "6e": ActionCode("", [], "Phone Ringing", "", ""),
    "6s": ActionCode("", [["0", True, "", "1", "Contact="]], "Phone Ringing", "", ""),
    "701t": ActionCode(
        "",
        [
            ["0", True, "Button", "0", "Button"],
            ["1", True, "Repeat Times", "0", "Repeat Times"],
        ],
        "Dpad",
        "55",
        "True",
    ),
    "702624035e": ActionCode(
        "",
        [["0", True, "", "5", "Gesture"]],
        "Fingerprint Gesture",
        "",
        "",
    ),
    "702t": ActionCode(
        "",
        [
            ["0", True, "Text", "1", "Text"],
            ["1", True, "Repeat Times", "0", "Repeat Times"],
        ],
        "Type",
        "55",
        "True",
    ),
    "703953103t": ActionCode("1040876951t", [], "KLWP Live Wallpaper", "", ""),
    "703t": ActionCode(
        "",
        [["0", True, "Button", "0", "Button"]],
        "Button",
        "55",
        "True",
    ),
    "71t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
            ["2", True, "Text Size", "0", ", Text Size="],
        ],
        "Element Text Size",
        "102",
        "True",
    ),
    "721t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "Set", "3", ["e", ", Set"]],
        ],
        "Zoom Visibility",
        "125",
        "False",
    ),
    "731t": ActionCode("", [], "Take Call", "90", "False"),
    "732t": ActionCode("", [["0", True, "Set", "3", "Set"]], "Radio", "90", "False"),
    "733t": ActionCode(
        "",
        [["0", True, "Output Variables", "5", "Output Variables"]],
        "End Call",
        "90",
        "False",
    ),
    "734t": ActionCode("", [], "Silence Ringer", "90", "False"),
    "735t": ActionCode(
        "",
        [["0", True, "Mode", "0", "Mode"]],
        "Mobile Data 2G/3G",
        "80",
        "False",
    ),
    "73t": ActionCode(
        "",
        [
            ["0", True, "Scene Name", "1", "Scene Name="],
            ["1", True, "Element", "1", ", Element="],
        ],
        "Element Destroy",
        "102",
        "True",
    ),
    "740t": ActionCode(
        "",
        [["0", True, "Element", "1", "Element="], ["1", True, "Text", "1", ", Text="]],
        "Zoom Text",
        "125",
        "False",
    ),
    "741t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "Text Size", "0", ", Text Size="],
        ],
        "Zoom Text Size",
        "125",
        "False",
    ),
    "742t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "Colour", "1", ", Text Color="],
        ],
        "Zoom Text Colour",
        "125",
        "False",
    ),
    "760t": ActionCode(
        "",
        [["0", True, "Element", "1", "Element="], ["1", True, "Set", "0", ", Set="]],
        "Zoom Alpha",
        "125",
        "False",
    ),
    "761t": ActionCode(
        "",
        [["0", True, "Element", "1", "Element="], ["1", False, "URI", "1", ", URL="]],
        "Zoom Image",
        "125",
        "False",
    ),
    "762t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "Colour", "1", ", Color="],
            ["2", True, "End Colour", "1", ", End Color="],
        ],
        "Zoom Colour",
        "125",
        "False",
    ),
    "774351906t": ActionCode("1040876951t", [], "Join Action", "", ""),
    "775t": ActionCode(
        "",
        [
            ["0", True, "Variable", "1", "Variable="],
            ["1", True, "File", "1", ", File="],
        ],
        "Write Binary",
        "50",
        "True",
    ),
    "776t": ActionCode(
        "",
        [["0", True, "File", "1", "File"], ["1", True, "To Var", "1", "To Var"]],
        "Read Binary",
        "50",
        "True",
    ),
    "778682267t": ActionCode("1040876951t", [], "AutoInput Gestures", "", ""),
    "779t": ActionCode(
        "",
        [
            ["0", False, "Title", "1", "Title="],
            ["1", True, "Warn Not Exist", "3", "Warn Not Exist"],
        ],
        "Notify Cancel",
        "10",
        "False",
    ),
    "793t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "State", "0", ", State="],
        ],
        "Zoom State",
        "125",
        "False",
    ),
    "794294329t": ActionCode("1040876951t", [], "AutoSheets Add Sheet", "", ""),
    "794t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "Orientation", "0", [", Orientation=", "l", "57"]],
            ["2", True, "X", "0", ", X="],
            ["3", True, "Y", "0", ", Y="],
        ],
        "Zoom Position",
        "125",
        "False",
    ),
    "795t": ActionCode(
        "",
        [
            ["0", True, "Element", "1", "Element="],
            ["1", True, "Orientation", "0", [", Orientation=", "l", "57"]],
            ["2", True, "Width", "0", ", Width="],
            ["3", True, "Height", "0", ", Height="],
        ],
        "Zoom Size",
        "125",
        "False",
    ),
    "7e": ActionCode(
        "",
        [
            ["0", True, "", "0", ["Type=", "l", "7e"]],
            ["1", True, "", "1", ", Sender="],
            ["2", True, "", "1", ", Content="],
            ["3", True, "", "1", ", SIM Card="],
            ["4", True, "", "1", ", MMS Body="],
        ],
        "Received Text",
        "",
        "",
    ),
    "7s": ActionCode("", [], "Cell Near", "", ""),
    "801498676t": ActionCode("1040876951t", [], "AutoSpotify Albums", "", ""),
    "804t": ActionCode("", [], "Input Method Select", "55", "False"),
    "806t": ActionCode(
        "",
        [["0", True, "Block Time (Check Help)", "0", "Block Time="]],
        "Turn On",
        "40",
        "False",
    ),
    "808t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Auto Brightness",
        "40",
        "False",
    ),
    "80s": ActionCode("", [], "Docked", "", ""),
    "810t": ActionCode(
        "",
        [
            ["0", True, "Level", "0", "Level="],
            ["1", True, "Disable Safeguard", "3", ["e", ", Disable Safeguard"]],
            ["2", True, "Ignore Current Level", "3", ["e", ", Ignore Current Level"]],
            ["3", True, "Immediate Effect", "3", "Immediate Effect"],
        ],
        "Display Brightness",
        "40",
        "False",
    ),
    "811079103t": ActionCode("1040876951t", [], "AutoInput Global Action", "", ""),
    "812t": ActionCode(
        "",
        [
            ["0", True, "Secs", "0", "Secs="],
            ["1", True, "Mins", "0", ", Mins="],
            ["2", True, "Hours", "0", ", Hours="],
        ],
        "Display Timeout",
        "40",
        "False",
    ),
    "815t": ActionCode(
        "",
        [
            ["0", True, "Type", "0", ["Type=", "l", "815"]],
            ["1", False, "Match", "1", ", Match="],
            ["2", True, "Store Result In", "1", ", Store Result In="],
        ],
        "List Apps",
        "15",
        "False",
    ),
    "819222800t": ActionCode("1040876951t", [], "AutoSpotify Tracks", "", ""),
    "820t": ActionCode(
        "",
        [["0", True, "Mode", "0", ["Mode=", "l", "820"]]],
        "Stay On",
        "40",
        "False",
    ),
    "822t": ActionCode(
        "",
        [["0", True, "Set", "3", ["Set=", "l", "switch_set"]]],
        "Display AutoRotate",
        "40",
        "False",
    ),
    "8618362t": ActionCode("1040876951t", [], "AutoSpotify Notification", "", ""),
    "864692752t": ActionCode("1040876951t", [], "Join", "", ""),
    "877t": ActionCode(
        "",
        [
            ["0", False, "Action", "1", "Action="],
            ["1", True, "Cat", "0", [", Mode=", "l", "877"]],
            ["2", False, "Mime Type", "1", ", Mime Type="],
            ["3", False, "Data", "1", ", Data="],
            ["4", False, "Extra", "1", ", Extra="],
            ["5", False, "Extra", "1", ", Extra="],
            ["6", False, "Extra", "1", ", Extra="],
            ["7", False, "Package", "1", ", Package="],
            ["8", False, "Class", "1", ", Class="],
            ["9", True, "Target", "0", [", Target=", "l", "877a"]],
        ],
        "Send Intent",
        "104",
        "True",
    ),
    "888t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Value", "0", ", Value="],
            ["2", True, "Wrap Around", "0", ", Wrap Around="],
        ],
        "Variable Add",
        "120",
        "False",
    ),
    "890t": ActionCode(
        "",
        [
            ["0", True, "Name", "1", "Name="],
            ["1", True, "Value", "0", ", Value="],
            ["2", True, "Wrap Around", "0", ", Wrap Around="],
        ],
        "Variable Subtract",
        "120",
        "False",
    ),
    "8e": ActionCode("", [], "Received Data SMS", "", ""),
    "900t": ActionCode(
        "",
        [
            ["0", False, "Directory", "1", "Directory="],
            ["1", False, "Match", "1", ", Match="],
            ["2", True, "Include Hidden Files", "3", ["e", ", Include Hidden Files"]],
        ],
        "Browse Files",
        "50",
        "False",
    ),
    "901t": ActionCode(
        "",
        [["0", True, "Source", "0", ["Set=", "l", "901"]]],
        "Stop Location",
        "60",
        "False",
    ),
    "902t": ActionCode(
        "",
        [
            ["0", True, "Source", "0", ["Set=", "l", "901"]],
            ["1", True, "Timeout (Seconds)", "0", ", Timeout (Seconds)="],
            [
                "2",
                True,
                "Continue Task Immediately",
                "3",
                ["e", ", Continue Task Immediately"],
            ],
            ["3", True, "Keep Tracking", "3", ["e", ", Keep Tracking"]],
        ],
        "Get Location",
        "60",
        "True",
    ),
    "903t": ActionCode(
        "",
        [
            ["0", False, "Title", "1", "Title="],
            ["1", True, "Language Model", "0", [", Mode=", "l", "903"]],
            ["2", False, "Language", "1", ", Language="],
            ["3", True, "Maximum Results", "0", ", Maximum Results="],
            ["4", True, "Timeout (Seconds)", "0", ", Timeout="],
            ["5", True, "Hide Dialog", "3", ["e", ", Hide Dialog"]],
            ["6", True, "Output Variables", "5", "Output Variables"],
        ],
        "Get Voice",
        "55",
        "True",
    ),
    "904t": ActionCode("", [], "Voice Command", "55", "False"),
    "905t": ActionCode(
        "",
        [["0", True, "Mode", "0", ["Mode=", "l", "905"]]],
        "Location Mode",
        "60",
        "True",
    ),
    "906355163t": ActionCode("1040876951t", [], "AutoWear Voice Screen", "", ""),
    "906686306e": ActionCode("1040876951t", [], "AutoLocation Geofences", "", ""),
    "906t": ActionCode(
        "",
        [["0", True, "Mode", "0", ["Mode=", "l", "906"]]],
        "Immersive Mode",
        "40",
        "True",
    ),
    "907418897t": ActionCode("1040876951t", [], "AutoTools Action Report", "", ""),
    "907t": ActionCode(
        "",
        [["0", False, "Icons To Hide", "1", "Icons To Hide="]],
        "Status Bar Icons",
        "40",
        "True",
    ),
    "909t": ActionCode(
        "",
        [["0", True, "Type", "0", ["Mode=", "l", "909"]]],
        "Contacts",
        "90",
        "False",
    ),
    "90t": ActionCode(
        "",
        [
            ["0", False, "Number", "1", "Number="],
            ["1", True, "Auto Dial", "3", ["e", ", Auto Dial"]],
            ["2", False, "SIM Card", "1", ", Sim Card="],
        ],
        "Call",
        "90",
        "False",
    ),
    "910t": ActionCode(
        "",
        [["0", True, "Action", "0", ["Mode=", "l", "910"]]],
        "Call Log",
        "90",
        "False",
    ),
    "911t": ActionCode(
        "",
        [["0", False, "Name", "1", "Name"], ["1", True, "Set", "3", "Set"]],
        "Gentle Alarm",
        "130",
        "False",
    ),
    "915t": ActionCode(
        "",
        [
            ["0", True, "CPU", "0", "CPU"],
            ["1", True, "Governor", "1", "Governor"],
            ["2", True, "Min. Frequency", "0", "Min. Frequency"],
            ["3", True, "Max. Frequency", "0", "Max. Frequency"],
        ],
        "CPU",
        "104",
        "True",
    ),
    "917310686t": ActionCode("1040876951t", [], "AutoSpotify Artists", "", ""),
    "918403287t": ActionCode("1040876951t", [], "AutoNotification Categories", "", ""),
    "921575593t": ActionCode("1040876951t", [], "AutoInput Keyguard", "", ""),
    "940160580t": ActionCode("1040876951t", [], "AutoShare", "", ""),
    "941t": ActionCode(
        "",
        [
            ["0", True, "Code", "1", "Code="],
            ["1", True, "Layout", "1", ", Layout="],
            ["2", True, "Timeout (Seconds)", "0", ", Timeout (Seconds)"],
            ["3", True, "Show Over Keyguard", "3", ["e", ", Show Over Keyguard"]],
        ],
        "HTML Popup",
        "10",
        "False",
    ),
    "956t": ActionCode("", [], "NFC Settings", "30", "False"),
    "957t": ActionCode("", [], "Android Beam Settings", "30", "False"),
    "958t": ActionCode("", [], "NFC Payment Settings", "30", "False"),
    "959t": ActionCode("", [], "Dream Settings", "30", "False"),
    "95t": ActionCode(
        "",
        [
            ["0", False, "Number Match", "1", "Number Match="],
            ["1", True, "Info", "3", ["e", "Info"]],
        ],
        "Call Block",
        "90",
        "False",
    ),
    "96135575t": ActionCode("1040876951t", [], "AutoLocation Info", "", ""),
    "96585332t": ActionCode("1040876951t", [], "AutoWear Settings", "", ""),
    "97t": ActionCode(
        "",
        [
            ["0", False, "From Match", "1", "From Match="],
            ["1", True, "To", "1", ", To="],
            ["2", True, "Info", "3", ["e", ", Info"]],
        ],
        "Call Divert",
        "90",
        "False",
    ),
    "985050481t": ActionCode("1040876951t", [], "Actions", "", ""),
    "987t": ActionCode("", [], "Soft Keyboard", "55", "False"),
    "988t": ActionCode(
        "",
        [
            ["0", True, "Set", "3", ["Set=", "l", "switch_set"]],
            ["1", True, "Go Home", "3", ["e", ", Go Home"]],
        ],
        "Car Mode",
        "40",
        "False",
    ),
    "989t": ActionCode(
        "",
        [["0", True, "Mode", "0", "Mode"]],
        "Night Mode",
        "40",
        "False",
    ),
    "999t": ActionCode(
        "",
        [["0", True, "Set", "1", "Set"], ["1", True, "To", "0", "To"]],
        "Set Light",
        "10",
        "False",
    ),
    "99t": ActionCode(
        "",
        [
            ["0", False, "Number", "1", "Number="],
            ["1", True, "Info", "3", ["e", "Info"]],
        ],
        "Call Revert",
        "90",
        "False",
    ),
    "ButtonElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "1", ", Label="],
            ["2", True, "", "0", ", Label Size="],
            ["3", True, "", "0", ", Label Width Scale %="],
            ["4", True, "", "1", ", Label Color="],
            ["5", True, "", "1", ", Font="],
            ["6", True, "", "0", [", Position=", "l", "TextElement1"]],
            ["7", True, "", "8", ", Icon="],
        ],
        "",
        "",
        "",
    ),
    "CheckBoxElement": ActionCode(
        "",
        [["0", True, "", "1", "Name="], ["1", True, "", "0", ["1", "e", ", Checked"]]],
        "",
        "",
        "",
    ),
    "DoodleElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", ", Doodle="],
            ["2", True, "", "0", ", Alpha="],
        ],
        "",
        "",
        "",
    ),
    "EditTextElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "1", ", Text="],
            ["2", True, "", "0", ", Text Size="],
            ["3", True, "", "0", ", Text Width Scale Percent="],
            ["4", True, "", "1", ", Text Color="],
            ["5", True, "", "1", ", Font="],
            ["6", True, "", "0", [", Position=", "l", "TextElement1"]],
            ["7", True, "", "0", [", Input Type=", "l", "EditTextElement"]],
            ["8", True, "", "0", ", Maximum Characters="],
        ],
        "",
        "",
        "",
    ),
    "ImageElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "8", ", Image="],
            ["2", True, "", "0", ", Alpha="],
        ],
        "",
        "",
        "",
    ),
    "ListElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Source=", "l", "ListElement1"]],
            ["2", True, "", "1", [", Selection Mode=", "l", "ListElement2"]],
            ["3", True, "", "0", [", Selection Mode=", "l", "ListElement2"]],
            ["5", True, "", "0", ", Horizontal Space="],
            ["6", True, "", "0", ", Vertical Space="],
        ],
        "",
        "",
        "",
    ),
    "ListElementItem": ActionCode("", [], "", "", ""),
    "MenuElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Source=", "l", "ListElement1"]],
            ["2", True, "", "0", [", Selection Mode=", "l", "ListElement2"]],
            ["3", True, "", "0", ", Horizontal Space="],
            ["4", True, "", "0", ", Vertical Space="],
        ],
        "",
        "",
        "",
    ),
    "OvalElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Shader=", "l", "RectElement1"]],
            ["2", True, "", "1", ", Color="],
            ["3", True, "", "1", ", End Color="],
            ["4", True, "", "0", ", Border Width="],
            ["5", True, "", "1", ", Border Color="],
        ],
        "",
        "",
        "",
    ),
    "PickerElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "1", ", Min="],
            ["2", True, "", "1", ", Max="],
            ["3", True, "", "1", ", Default="],
            ["4", True, "", "0", ["", "e", ", Wrap Around"]],
            ["5", True, "", "0", [", Format=", "l", "NumberPickerElement"]],
        ],
        "",
        "",
        "",
    ),
    "PropertiesElement": ActionCode(
        "",
        [
            ["0", True, "", "0", [", Property Type=", "l", "PropertyElement1"]],
            ["1", True, "", "0", [", Orientation=", "l", "PropertyElement2"]],
            ["2", True, "", "1", ", Background_Color="],
            ["3", True, "", "0", [", Property Type=", "l", "PropertyElement3"]],
            ["4", True, "", "1", ", Title="],
            ["5", True, "", "1", ", Subtitle="],
            ["6", True, "", "8", ", Icon="],
            ["7", True, "", "1", ", Tab Labels="],
        ],
        "",
        "",
        "",
    ),
    "RectElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Shader=", "l", "RectElement1"]],
            ["2", True, "", "1", ", Color="],
            ["3", True, "", "1", ", End Color="],
            ["4", True, "", "0", ", Border Width="],
            ["5", True, "", "1", ", Border XColor="],
            ["6", True, "", "0", ", Corner Radius="],
            ["7", True, "", "0", [", Rounded Corners=", "l", "RectElement2"]],
        ],
        "",
        "",
        "",
    ),
    "SceneElement": ActionCode(
        "Map",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "1", ", Lat/Long="],
            ["2", True, "", "0", ", Zoom="],
            ["3", True, "", "0", ["", "e", ", Show Traffic"]],
            ["4", True, "", "0", ["", "e", ", Show Satellite"]],
            ["5", True, "", "0", ["", "e", ", Show Roads"]],
        ],
        "Map",
        "",
        "",
    ),
    "SliderElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Orientation=", "l", "SliderElement1"]],
            ["2", True, "", "0", ", Min="],
            ["3", True, "", "0", ", Max="],
            ["4", True, "", "0", ", Default="],
            ["5", True, "", "0", [", Show Indicators=", "l", "SliderElement2"]],
            ["6", True, "", "8", ", Icon="],
        ],
        "",
        "",
        "",
    ),
    "SpinnerElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Source=", "l", "ListElement1"]],
            ["2", True, "", "1", ", Variable="],
            ["4", True, "", "None", ", Popup Background Color="],
        ],
        "",
        "",
        "",
    ),
    "SwitchElement": ActionCode(
        "",
        [["0", True, "", "1", "Name="], ["1", True, "", "0", ["", "e", ", Checked"]]],
        "",
        "",
        "",
    ),
    "TextElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "1", ", Text="],
            ["2", True, "", "0", ", Text Size="],
            ["3", True, "", "0", ", Text Width Scale Percent (100=0%)="],
            ["4", True, "", "1", ", Text Color="],
            ["5", True, "", "1", ", Font="],
            ["6", True, "", "0", [", Position=", "l", "TextElement1"]],
            ["7", True, "", "0", [", Vertical Fit Mode=", "l", "TextElement2"]],
            ["8", True, "", "0", [", Text Format=", "l", "TextElement3"]],
        ],
        "",
        "",
        "",
    ),
    "ToggleElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", ["", "e", ", On"]],
            ["2", True, "", "1", ", Off Label="],
            ["3", True, "", "1", ", On Label="],
            ["4", True, "", "0", ", Label Size="],
            ["5", True, "", "0", ", Label Width Width Scale Percent (100=0%)="],
            ["6", True, "", "1", ", Label Color="],
        ],
        "",
        "",
        "",
    ),
    "WebElement": ActionCode(
        "",
        [
            ["0", True, "", "1", "Name="],
            ["1", True, "", "0", [", Mode=", "l", "WebElement"]],
            ["2", True, "", "1", ", Source="],
            ["3", True, "", "0", ["", "e", ", Allow Phone Access"]],
            ["4", True, "", "1", ["", "e", ", Self Handle Links"]],
            ["5", True, "", "1", ["", "e", ", DB API"]],
            ["6", True, "", "1", ["", "e", ", Support Popups"]],
            ["7", True, "", "0", ", User Agent="],
        ],
        "",
        "",
        "",
    ),
}
